@@ -5,6 +5,7 @@
 
 #include "boardadmin.h"
 #include "boardview.h"
+#include "toolbar.h"
 
 #include "skeleton/msgdiag.h"
 
@@ -24,6 +25,7 @@
 #include "controlid.h"
 #include "prefdiagfactory.h"
 #include "httpcode.h"
+#include "controlutil.h"
 #include "colorid.h"
 #include "fontid.h"
 
@@ -89,8 +91,9 @@ enum
 
 
 // set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED ) を指定して append_columnする
-#define APPEND_COLUMN(title,model) do{ \
-Gtk::TreeView::Column* col = Gtk::manage( new Gtk::TreeViewColumn( title, model ) ); \
+#define APPEND_COLUMN(col,title,model) do{                    \
+if( ! col ) delete col; \
+col = Gtk::manage( new Gtk::TreeViewColumn( title, model ) );   \
 col->set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED ); \
 m_treeview.append_column( *col ); \
 }while(0)
@@ -99,29 +102,42 @@ m_treeview.append_column( *col ); \
 BoardView::BoardView( const std::string& url,const std::string& arg1, const std::string& arg2 )
     : SKELETON::View( url ),
       m_treeview( CONFIG::get_fontname( FONT_BOARD ), COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN ),
+      m_col_mark( NULL ),
+      m_col_id( NULL ),
+      m_col_subject( NULL ),
+      m_col_res( NULL ),
+      m_col_str_load( NULL ),     
+      m_col_str_new( NULL ),
+      m_col_since( NULL ),
+      m_col_write( NULL ),
+      m_col_speed( NULL ),
       m_col( COL_NUM_COL ),
       m_previous_col( COL_NUM_COL ),
       m_sortmode( SORTMODE_ASCEND ),
       m_previous_sortmode( false ),
-      m_toolbar( SESSION::get_show_board_toolbar() )
+      m_updated( false ),
+      m_loading( false )
 {
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
 
-    m_toolbar.m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BoardView::slot_active_search ) );
-    m_toolbar.m_button_close.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::close_view ) );
-    m_toolbar.m_button_reload.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::reload ) );
-    m_toolbar.m_button_stop.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::stop ) );
-    m_toolbar.m_button_new_article.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_new_article ) );
-    m_toolbar.m_button_delete.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_delete ) );
-    m_toolbar.m_button_favorite.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_favorite ) );
-    m_toolbar.m_button_up_search.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_up_search ) );
-    m_toolbar.m_button_down_search.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_down_search ) );
-    m_toolbar.m_button_search_cache.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_search_cache ) );
-    m_toolbar.m_button_preferences.signal_clicked().connect( sigc::mem_fun(*this, &BoardView::slot_push_preferences ) );
-    m_toolbar.m_entry_search.signal_operate().connect( sigc::mem_fun( *this, &BoardView::slot_entry_operate ) );
+    set_toolbar( Gtk::manage( new BoardToolBar() ) );
 
-    pack_start( m_toolbar, Gtk::PACK_SHRINK );    
+    get_boardtoolbar()->get_close_button().signal_clicked().connect( sigc::mem_fun( *this, &BoardView::close_view ) );
+    get_boardtoolbar()->m_entry_search.signal_changed().connect( sigc::mem_fun( *this, &BoardView::slot_changed_search ) );
+    get_boardtoolbar()->m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BoardView::slot_active_search ) );
+    get_boardtoolbar()->m_button_reload.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::reload ) );
+    get_boardtoolbar()->m_button_stop.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::stop ) );
+    get_boardtoolbar()->m_button_new_article.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_new_article ) );
+    get_boardtoolbar()->m_button_delete.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_delete ) );
+    get_boardtoolbar()->m_button_favorite.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_favorite ) );
+    get_boardtoolbar()->m_button_up_search.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_up_search ) );
+    get_boardtoolbar()->m_button_down_search.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_down_search ) );
+    get_boardtoolbar()->m_entry_search.signal_operate().connect( sigc::mem_fun( *this, &BoardView::slot_entry_operate ) );
+
+    if( SESSION::get_show_board_toolbar() ) get_boardtoolbar()->show_toolbar();
+
+    pack_start( *get_boardtoolbar(), Gtk::PACK_SHRINK );    
     pack_start( m_scrwin );
     show_all_children();    
 
@@ -145,16 +161,207 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
 
 #endif
 
-    // columnのappend
-    APPEND_COLUMN( COLUMN_TITLE_MARK, m_columns.m_col_mark );
-    APPEND_COLUMN( COLUMN_TITLE_ID, m_columns.m_col_id );
-    APPEND_COLUMN( COLUMN_TITLE_NAME, m_columns.m_col_subject );
-    APPEND_COLUMN( COLUMN_TITLE_RES, m_columns.m_col_res );
-    APPEND_COLUMN( COLUMN_TITLE_LOAD, m_columns.m_col_str_load );
-    APPEND_COLUMN( COLUMN_TITLE_NEW, m_columns.m_col_str_new );
-    APPEND_COLUMN( COLUMN_TITLE_SINCE, m_columns.m_col_since );
-    APPEND_COLUMN( COLUMN_TITLE_WRITE, m_columns.m_col_write );
-    APPEND_COLUMN( COLUMN_TITLE_SPEED, m_columns.m_col_speed );
+    // 列のappend
+    update_columns();
+
+    // ソート関数セット
+    m_liststore->set_sort_func( COL_MARK, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );    
+    m_liststore->set_sort_func( COL_ID, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_SUBJECT, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_RES, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_STR_LOAD, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_STR_NEW, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_SINCE, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_WRITE, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_SPEED, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
+    
+    m_treeview.sig_button_press().connect( sigc::mem_fun(*this, &BoardView::slot_button_press ) );
+    m_treeview.sig_button_release().connect( sigc::mem_fun(*this, &BoardView::slot_button_release ) );
+    m_treeview.sig_motion_notify().connect( sigc::mem_fun(*this, &BoardView::slot_motion_notify ) );
+    m_treeview.sig_key_press().connect( sigc::mem_fun(*this, &BoardView::slot_key_press ) );
+    m_treeview.sig_key_release().connect( sigc::mem_fun(*this, &BoardView::slot_key_release ) );
+    m_treeview.sig_scroll_event().connect( sigc::mem_fun(*this, &BoardView::slot_scroll_event ) );
+
+    // D&D設定
+    m_treeview.set_reorderable_view( true );
+    m_treeview.sig_drag_begin().connect( sigc::mem_fun(*this, &BoardView::slot_drag_begin ) );
+    m_treeview.sig_drag_end().connect( sigc::mem_fun(*this, &BoardView::slot_drag_end ) );
+
+
+    // ポップアップメニューの設定
+    // アクショングループを作ってUIマネージャに登録
+    action_group() = Gtk::ActionGroup::create();
+    action_group()->add( Gtk::Action::create( "BookMark", "ブックマーク設定/解除(_B)" ),
+                         sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_AUTO ) );
+    action_group()->add( Gtk::Action::create( "SetBookMark", "ブックマーク設定(_S)" ),  // 未使用
+                         sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_SET ) );
+    action_group()->add( Gtk::Action::create( "UnsetBookMark", "ブックマーク解除(_U)" ),    // 未使用
+                         sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_UNSET ) );
+    action_group()->add( Gtk::Action::create( "OpenTab", "タブで開く(_T)" ), sigc::mem_fun( *this, &BoardView::slot_open_tab ) );
+    action_group()->add( Gtk::Action::create( "Favorite_Article", "スレをお気に入りに追加(_F)..." ), sigc::mem_fun( *this, &BoardView::slot_favorite_thread ) );
+    action_group()->add( Gtk::Action::create( "Favorite_Board", "板をお気に入りに登録(_A)" ), sigc::mem_fun( *this, &BoardView::slot_favorite_board ) );
+    action_group()->add( Gtk::Action::create( "GotoTop", "一番上に移動(_T)" ), sigc::mem_fun( *this, &BoardView::goto_top ) );
+    action_group()->add( Gtk::Action::create( "GotoBottom", "一番下に移動(_M)" ), sigc::mem_fun( *this, &BoardView::goto_bottom ) );
+    action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );
+    action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardView::delete_view ) );
+    action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)" ), sigc::mem_fun( *this, &BoardView::open_selected_rows ) );
+    action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_C)" ), sigc::mem_fun( *this, &BoardView::slot_copy_url ) );
+    action_group()->add( Gtk::Action::create( "CopyTitleURL", "タイトルとURLをコピー(_U)" ), sigc::mem_fun( *this, &BoardView::slot_copy_title_url ) );
+    action_group()->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く(_W)" ), sigc::mem_fun( *this, &BoardView::slot_open_browser ) );
+    action_group()->add( Gtk::Action::create( "AboneThread", "スレをあぼ〜んする(_N)" ), sigc::mem_fun( *this, &BoardView::slot_abone_thread ) );
+    action_group()->add( Gtk::Action::create( "PreferenceArticle", "スレのプロパティ(_I)..." ), sigc::mem_fun( *this, &BoardView::slot_preferences_article ) );
+    action_group()->add( Gtk::Action::create( "Preference", "板のプロパティ(_P)..." ), sigc::mem_fun( *this, &BoardView::show_preference ) );
+    action_group()->add( Gtk::Action::create( "SaveDat", "datファイルを保存(_S)..." ), sigc::mem_fun( *this, &BoardView::slot_save_dat ) );
+
+    ui_manager() = Gtk::UIManager::create();    
+    ui_manager()->insert_action_group( action_group() );
+
+    Glib::ustring str_ui = 
+    "<ui>"
+
+    // 通常
+    "<popup name='popup_menu'>"
+    "<menuitem action='BookMark'/>"
+    "<separator/>"
+    "<menuitem action='OpenTab'/>"
+    "<menuitem action='OpenBrowser'/>"
+    "<separator/>"
+    "<menuitem action='CopyURL'/>"
+    "<menuitem action='CopyTitleURL'/>"
+    "<separator/>"
+    "<menuitem action='SaveDat'/>"
+    "<separator/>"
+    "<menuitem action='Favorite_Article'/>"
+    "<separator/>"
+    "<menuitem action='AboneThread'/>"
+    "<separator/>"
+    "<menu action='Delete_Menu'>"
+    "<menuitem action='Delete'/>"
+    "</menu>"
+    "<separator/>"
+    "<menuitem action='PreferenceArticle'/>"
+    "<menuitem action='Preference'/>"
+    "</popup>"
+
+
+    // 通常 + 複数
+    "<popup name='popup_menu_mul'>"
+    "<menuitem action='OpenRows'/>"
+    "<separator/>"
+    "<menuitem action='SetBookMark'/>"
+    "<menuitem action='UnsetBookMark'/>"
+    "<separator/>"
+    "<menuitem action='Favorite_Article'/>"
+    "<separator/>"
+    "<menuitem action='AboneThread'/>"
+    "<separator/>"
+    "<menu action='Delete_Menu'>"
+    "<menuitem action='Delete'/>"
+    "</menu>"
+    "</popup>"
+
+
+    // お気に入りボタン押した時のメニュー
+    "<popup name='popup_menu_favorite'>"
+    "<menuitem action='Favorite_Article'/>"
+    "<menuitem action='Favorite_Board'/>"
+    "</popup>"
+
+
+    // 削除ボタン押した時のメニュー
+    "<popup name='popup_menu_delete'>"
+    "<menuitem action='Delete'/>"
+    "</popup>"
+
+
+    "</ui>";
+
+    ui_manager()->add_ui_from_string( str_ui );
+
+    // ポップアップメニューにキーアクセレータを表示
+    Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu" ) );
+    CONTROL::set_menu_motion( popupmenu );
+
+    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_mul" ) );
+    CONTROL::set_menu_motion( popupmenu );
+
+    // マウスジェスチォ可能
+    set_enable_mg( true );
+
+    // オートリロード可
+    set_enable_autoreload( true );
+
+    // コントロールモード設定
+    get_control().add_mode( CONTROL::MODE_BOARD );
+}
+
+
+BoardView::~BoardView()
+{
+#ifdef _DEBUG    
+    std::cout << "BoardView::~BoardView : " << get_url() << std::endl;
+#endif
+    DBTREE::board_save_info( get_url() );
+    save_column_width();
+}
+
+
+// アイコンのID取得
+const int BoardView::get_icon( const std::string& iconname )
+{
+    int id = ICON::NONE;
+
+    if( iconname == "default" ) id = ICON::BOARD;
+    if( iconname == "loading" ) id = ICON::LOADING;
+    if( iconname == "loading_stop" ) id = ICON::LOADING_STOP;
+    if( iconname == "updated" ) id = ICON::BOARD_UPDATED;
+
+    return id;
+}
+
+
+// 更新した
+const bool BoardView::is_updated()
+{
+    int code = DBTREE::board_code( get_url() );
+    return ( ( code == HTTP_OK || code == HTTP_PARTIAL_CONTENT ) && m_updated );
+}
+
+
+//
+// コピー用URL(メインウィンドウのURLバーなどに表示する)
+//
+const std::string BoardView::url_for_copy()
+{
+    return DBTREE::url_boardbase( get_url() );
+}
+
+
+
+//
+// 列項目の更新
+//
+void BoardView::update_columns()
+{
+    m_treeview.remove_all_columns();
+
+    int num = 0;
+    for(;;){
+        int item = SESSION::get_item_board( num );
+        if( item == ITEM_END ) break;
+        switch( item ){
+            case ITEM_MARK: APPEND_COLUMN( m_col_mark, ITEM_NAME_MARK, m_columns.m_col_mark ); break;
+            case ITEM_ID: APPEND_COLUMN( m_col_id, ITEM_NAME_ID, m_columns.m_col_id ); break;
+            case ITEM_NAME: APPEND_COLUMN( m_col_subject, ITEM_NAME_NAME, m_columns.m_col_subject ); break;
+            case ITEM_RES: APPEND_COLUMN( m_col_res, ITEM_NAME_RES, m_columns.m_col_res ); break;
+            case ITEM_LOAD: APPEND_COLUMN( m_col_str_load, ITEM_NAME_LOAD, m_columns.m_col_str_load ); break;
+            case ITEM_NEW: APPEND_COLUMN( m_col_str_new, ITEM_NAME_NEW, m_columns.m_col_str_new ); break;
+            case ITEM_SINCE: APPEND_COLUMN( m_col_since, ITEM_NAME_SINCE, m_columns.m_col_since ); break;
+            case ITEM_LASTWRITE: APPEND_COLUMN( m_col_write, ITEM_NAME_LASTWRITE, m_columns.m_col_write ); break;
+            case ITEM_SPEED: APPEND_COLUMN( m_col_speed, ITEM_NAME_SPEED, m_columns.m_col_speed ); break;
+        }
+        ++num;
+    }
 
     // サイズを調整しつつソートの設定
     for( guint i = 0; i < COL_VISIBLE_END; i++ ){
@@ -264,160 +471,9 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
             }
         }
     }
-
-    // ソート関数セット
-    m_liststore->set_sort_func( COL_MARK, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );    
-    m_liststore->set_sort_func( COL_ID, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
-    m_liststore->set_sort_func( COL_SUBJECT, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
-    m_liststore->set_sort_func( COL_RES, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
-    m_liststore->set_sort_func( COL_STR_LOAD, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
-    m_liststore->set_sort_func( COL_STR_NEW, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
-    m_liststore->set_sort_func( COL_SINCE, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
-    m_liststore->set_sort_func( COL_WRITE, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
-    m_liststore->set_sort_func( COL_SPEED, sigc::mem_fun( *this, &BoardView::slot_compare_row ) );
-    
-    m_treeview.sig_button_press().connect( sigc::mem_fun(*this, &BoardView::slot_button_press ) );
-    m_treeview.sig_button_release().connect( sigc::mem_fun(*this, &BoardView::slot_button_release ) );
-    m_treeview.sig_motion_notify().connect( sigc::mem_fun(*this, &BoardView::slot_motion_notify ) );
-    m_treeview.sig_key_press().connect( sigc::mem_fun(*this, &BoardView::slot_key_press ) );
-    m_treeview.sig_key_release().connect( sigc::mem_fun(*this, &BoardView::slot_key_release ) );
-    m_treeview.sig_scroll_event().connect( sigc::mem_fun(*this, &BoardView::slot_scroll_event ) );
-
-    // D&D設定
-    m_treeview.set_reorderable_view( true );
-    m_treeview.sig_drag_begin().connect( sigc::mem_fun(*this, &BoardView::slot_drag_begin ) );
-    m_treeview.sig_drag_end().connect( sigc::mem_fun(*this, &BoardView::slot_drag_end ) );
-
-
-    // ポップアップメニューの設定
-    // アクショングループを作ってUIマネージャに登録
-    action_group() = Gtk::ActionGroup::create();
-    action_group()->add( Gtk::Action::create( "BookMark", "ブックマーク設定/解除"),
-                         sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_AUTO ) );
-    action_group()->add( Gtk::Action::create( "SetBookMark", "ブックマーク設定"),
-                         sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_SET ) );
-    action_group()->add( Gtk::Action::create( "UnsetBookMark", "ブックマーク解除"),
-                         sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_UNSET ) );
-    action_group()->add( Gtk::Action::create( "OpenTab", "タブで開く"), sigc::mem_fun( *this, &BoardView::slot_open_tab ) );
-    action_group()->add( Gtk::Action::create( "Favorite_Article", "スレをお気に入りに追加"), sigc::mem_fun( *this, &BoardView::slot_favorite_thread ) );
-    action_group()->add( Gtk::Action::create( "Favorite_Board", "板をお気に入りに登録"), sigc::mem_fun( *this, &BoardView::slot_favorite_board ) );
-    action_group()->add( Gtk::Action::create( "GotoTop", "一番上に移動"), sigc::mem_fun( *this, &BoardView::goto_top ) );
-    action_group()->add( Gtk::Action::create( "GotoBottom", "一番下に移動"), sigc::mem_fun( *this, &BoardView::goto_bottom ) );
-    action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );    
-    action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する"), sigc::mem_fun( *this, &BoardView::delete_view ) );
-    action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く"), sigc::mem_fun( *this, &BoardView::open_selected_rows ) );
-    action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー"), sigc::mem_fun( *this, &BoardView::slot_copy_url ) );
-    action_group()->add( Gtk::Action::create( "CopyTitleURL", "タイトルとURLをコピー"), sigc::mem_fun( *this, &BoardView::slot_copy_title_url ) );
-    action_group()->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く"), sigc::mem_fun( *this, &BoardView::slot_open_browser ) );
-    action_group()->add( Gtk::Action::create( "AboneThread", "スレをあぼ〜んする"), sigc::mem_fun( *this, &BoardView::slot_abone_thread ) );
-    action_group()->add( Gtk::Action::create( "PreferenceArticle", "スレのプロパティ"), sigc::mem_fun( *this, &BoardView::slot_preferences_article ) );
-    action_group()->add( Gtk::Action::create( "Preference", "板のプロパティ"), sigc::mem_fun( *this, &BoardView::slot_push_preferences ) );
-    action_group()->add( Gtk::Action::create( "SaveDat", "datファイルを保存"), sigc::mem_fun( *this, &BoardView::slot_save_dat ) );
-
-    ui_manager() = Gtk::UIManager::create();    
-    ui_manager()->insert_action_group( action_group() );
-
-    Glib::ustring str_ui = 
-    "<ui>"
-
-    // 通常
-    "<popup name='popup_menu'>"
-    "<menuitem action='BookMark'/>"
-    "<separator/>"
-    "<menuitem action='OpenTab'/>"
-    "<menuitem action='OpenBrowser'/>"
-    "<separator/>"
-    "<menuitem action='CopyURL'/>"
-    "<menuitem action='CopyTitleURL'/>"
-    "<separator/>"
-    "<menuitem action='SaveDat'/>"
-    "<separator/>"
-    "<menuitem action='Favorite_Article'/>"
-    "<separator/>"
-    "<menuitem action='AboneThread'/>"
-    "<separator/>"
-    "<menu action='Delete_Menu'>"
-    "<menuitem action='Delete'/>"
-    "</menu>"
-    "<separator/>"
-    "<menuitem action='PreferenceArticle'/>"
-    "<menuitem action='Preference'/>"
-    "</popup>"
-
-
-    // 通常 + 複数
-    "<popup name='popup_menu_mul'>"
-    "<menuitem action='OpenRows'/>"
-    "<separator/>"
-    "<menuitem action='SetBookMark'/>"
-    "<menuitem action='UnsetBookMark'/>"
-    "<separator/>"
-    "<menuitem action='Favorite_Article'/>"
-    "<separator/>"
-    "<menuitem action='AboneThread'/>"
-    "<separator/>"
-    "<menu action='Delete_Menu'>"
-    "<menuitem action='Delete'/>"
-    "</menu>"
-    "</popup>"
-
-
-    // お気に入りボタン押した時のメニュー
-    "<popup name='popup_menu_favorite'>"
-    "<menuitem action='Favorite_Article'/>"
-    "<menuitem action='Favorite_Board'/>"
-    "</popup>"
-
-
-    // 削除ボタン押した時のメニュー
-    "<popup name='popup_menu_delete'>"
-    "<menuitem action='Delete'/>"
-    "</popup>"
-
-
-    "</ui>";
-
-    ui_manager()->add_ui_from_string( str_ui );
-
-    // ポップアップメニューにキーアクセレータを表示
-    Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu" ) );
-    CONTROL::set_menu_motion( popupmenu );
-
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_mul" ) );
-    CONTROL::set_menu_motion( popupmenu );
-
-    // マウスジェスチォ可能
-    set_enable_mg( true );
-
-    // オートリロード可
-    set_enable_autoreload( true );
-
-    // コントロールモード設定
-    get_control().add_mode( CONTROL::MODE_BOARD );
 }
 
 
-BoardView::~BoardView()
-{
-#ifdef _DEBUG    
-    std::cout << "BoardView::~BoardView : " << get_url() << std::endl;
-#endif
-    DBTREE::board_save_info( get_url() );
-    save_column_width();
-}
-
-
-
-//
-// コピー用URL(メインウィンドウのURLバーなどに表示する)
-//
-const std::string BoardView::url_for_copy()
-{
-    return DBTREE::url_boardbase( get_url() );
-}
-
-
-
 //
 // i列目のIDを取得
 //
@@ -431,15 +487,15 @@ int BoardView::get_title_id( int col )
     std::string title = column->get_title();
     int id = -1;
 
-    if( title == COLUMN_TITLE_MARK ) id = COL_MARK;
-    else if( title == COLUMN_TITLE_ID ) id = COL_ID;
-    else if( title == COLUMN_TITLE_NAME ) id = COL_SUBJECT;
-    else if( title == COLUMN_TITLE_RES ) id = COL_RES;
-    else if( title == COLUMN_TITLE_LOAD ) id = COL_STR_LOAD;
-    else if( title == COLUMN_TITLE_NEW ) id = COL_STR_NEW;
-    else if( title == COLUMN_TITLE_SINCE ) id = COL_SINCE;
-    else if( title == COLUMN_TITLE_WRITE ) id = COL_WRITE;
-    else if( title == COLUMN_TITLE_SPEED ) id = COL_SPEED;
+    if( title == ITEM_NAME_MARK ) id = COL_MARK;
+    else if( title == ITEM_NAME_ID ) id = COL_ID;
+    else if( title == ITEM_NAME_NAME ) id = COL_SUBJECT;
+    else if( title == ITEM_NAME_RES ) id = COL_RES;
+    else if( title == ITEM_NAME_LOAD ) id = COL_STR_LOAD;
+    else if( title == ITEM_NAME_NEW ) id = COL_STR_NEW;
+    else if( title == ITEM_NAME_SINCE ) id = COL_SINCE;
+    else if( title == ITEM_NAME_LASTWRITE ) id = COL_WRITE;
+    else if( title == ITEM_NAME_SPEED ) id = COL_SPEED;
 
     return id;
 }
@@ -738,6 +794,17 @@ int BoardView::slot_compare_row( const Gtk::TreeModel::iterator& a, const Gtk::T
 }
 
 
+//
+// コマンド
+//
+bool BoardView::set_command( const std::string& command, const std::string& arg )
+{
+    if( command == "update_columns" ) update_columns();
+
+    return true;
+}
+
+
 //
 // クロック入力
 //
@@ -802,9 +869,6 @@ void BoardView::show_view()
     set_title( DBTREE::board_name( get_url() ) );
     BOARD::get_admin()->set_command( "set_title", get_url(), get_title() );
 
-    // タブにアイコンを表示
-    BOARD::get_admin()->set_command( "set_tabicon", get_url(), "loading" );
-
     // タブに名前をセット
     BOARD::get_admin()->set_command( "set_tablabel", get_url(), DBTREE::board_name( get_url() ) );
 
@@ -813,12 +877,16 @@ void BoardView::show_view()
 #endif
     m_liststore->clear();
     m_pre_query = std::string();
+    m_loading = true;
     
     // download 開始
     // 終わったら update_view() が呼ばれる
     DBTREE::board_download_subject( get_url() );
     set_status( "loading..." );
     BOARD::get_admin()->set_command( "set_status", get_url(), get_status() );
+
+    // タブにアイコンを表示
+    BOARD::get_admin()->set_command( "toggle_icon", get_url() );
 }
 
 
@@ -832,7 +900,7 @@ void BoardView::redraw_view()
     std::cout << "BoardView::redraw_view" << get_url() << std::endl;
 #endif  
 
-    m_search_invert = false;
+	    m_search_invert = false;
 
     // ソート状態回復
     m_col = DBTREE::board_view_sort_column( get_url() );
@@ -843,8 +911,6 @@ void BoardView::redraw_view()
 
     exec_sort();
     goto_top();
-
-    if( BOARD::get_admin()->has_focus() ) focus_view();
 }
 
 
@@ -871,8 +937,8 @@ void BoardView::update_view()
     std::cout << "BoardView::update_view " << get_url() << std::endl;
 #endif    
 
-    // 更新されたか
-    bool updated = false;
+    m_updated = false;
+    m_loading = false;
 
     // 画面消去
 #if GTKMMVER >= 280
@@ -911,7 +977,7 @@ void BoardView::update_view()
             update_row_common( art, row, id );
 
             // 更新があるかチェック
-            if( art->get_number_load() && art->get_number() > art->get_number_load() ) updated = true;
+            if( art->get_number_load() && art->get_number() > art->get_number_load() ) m_updated = true;
         }
 
 #if GTKMMVER >= 280
@@ -927,20 +993,10 @@ void BoardView::update_view()
     BOARD::get_admin()->set_command( "set_status", get_url(), get_status() );
 
     // タブのアイコン状態を更新
-    int code = DBTREE::board_code( get_url() );
-
-    // オートリロードモードでロード待ち
-    if( View::get_autoreload_mode() != AUTORELOAD_NOT ){
-        BOARD::get_admin()->set_command( "set_tabicon", get_url(), "loading_stop" );
-    }
-    // 更新あり   
-    else  if( ( code == HTTP_OK || code == HTTP_PARTIAL_CONTENT ) && updated ){
-        BOARD::get_admin()->set_command( "set_tabicon", get_url(), "update" );
-    }
-    // 通常
-    else BOARD::get_admin()->set_command( "set_tabicon", get_url(), "default" );
+    BOARD::get_admin()->set_command( "toggle_icon", get_url() );
 }
 
+
 void BoardView::focus_view()
 {
 #ifdef _DEBUG
@@ -1025,8 +1081,13 @@ void BoardView::operate_view( const int& control )
         case CONTROL::End:
             goto_bottom();
             break;
+
+            // 全て選択
+        case CONTROL::SelectAll:
+            slot_select_all();
+            break;
     
-            // 選択
+            // スレを開く
         case CONTROL::OpenArticleTab:
             open_tab = true;
         case CONTROL::OpenArticle:
@@ -1081,9 +1142,9 @@ void BoardView::operate_view( const int& control )
 
         case CONTROL::Delete:
         {
-            SKELETON::MsgDiag mdiag( NULL, "選択した行のログを削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-            mdiag.set_default_response( Gtk::RESPONSE_OK );
-            if( mdiag.run() != Gtk::RESPONSE_OK ) return;
+            SKELETON::MsgDiag mdiag( NULL, "選択した行のログを削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            mdiag.set_default_response( Gtk::RESPONSE_YES );
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
             delete_view();
             break;
         }
@@ -1095,13 +1156,17 @@ void BoardView::operate_view( const int& control )
 
         // 検索
         case CONTROL::Search:
-            m_search_invert = false;
-            m_toolbar.m_entry_search.grab_focus();
+            if( get_boardtoolbar() ){
+                m_search_invert = false;
+                get_boardtoolbar()->m_entry_search.grab_focus();
+            }
             break;
 
         case CONTROL::SearchInvert:
-            m_search_invert = true;
-            m_toolbar.m_entry_search.grab_focus();
+            if( get_boardtoolbar() ){
+                m_search_invert = true;
+                get_boardtoolbar()->m_entry_search.grab_focus();
+            }
             break;
 
         case CONTROL::SearchNext:
@@ -1202,8 +1267,10 @@ void BoardView::scroll_right()
 //
 void BoardView::toggle_toolbar()
 {
-    if( SESSION::get_show_board_toolbar() ) m_toolbar.show_toolbar();
-    else m_toolbar.hide_toolbar();
+    if( ! get_boardtoolbar() ) return;
+
+    if( SESSION::get_show_board_toolbar() ) get_boardtoolbar()->show_toolbar();
+    else get_boardtoolbar()->hide_toolbar();
 }
 
 
@@ -1243,6 +1310,12 @@ void BoardView::page_down()
 } 
    
 
+BoardToolBar* BoardView::get_boardtoolbar()
+{
+    return dynamic_cast< BoardToolBar* >( get_toolbar() );
+}
+
+
 //
 // ポップアップメニュー取得
 //
@@ -1355,35 +1428,41 @@ void BoardView::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel::Row
     if( art->is_bookmarked_thread() && art->enable_load() ){
         mark_val = COL_MARKVAL_BKMARKED_UPDATED;
         row[ m_columns.m_col_mark ] = ICON::get_icon( ICON::BKMARK_UPDATE );
+        art->show_updateicon( true );
     }
 
     // ブックマーク
     else if( art->is_bookmarked_thread() ){
         mark_val = COL_MARKVAL_BKMARKED;
         row[ m_columns.m_col_mark ] = ICON::get_icon( ICON::BKMARK );
+        art->show_updateicon( false );
     }
 
     // dat落ち
     else if( art->get_status() & STATUS_OLD ){
         mark_val = COL_MARKVAL_OLD;
         row[ m_columns.m_col_mark ] = ICON::get_icon( ICON::DOWN );
+        art->show_updateicon( false );
     }
 
     // キャッシュはあるが規定のレス数を越えていて全てのレスが既読
     else if( art->is_finished() ){
         mark_val = COL_MARKVAL_FINISHED;
         row[ m_columns.m_col_mark ] = ICON::get_icon( ICON::CHECK );
+        art->show_updateicon( false );
     }
 
     // 新着あり
     else if( art->is_cached() && art->enable_load() ){
         mark_val = COL_MARKVAL_UPDATED;
         row[ m_columns.m_col_mark ] = ICON::get_icon( ICON::UPDATE );
+        art->show_updateicon( true );
     }
     // キャッシュあり、新着無し
     else if( art->is_cached() ){
         mark_val = COL_MARKVAL_CACHED;
         row[ m_columns.m_col_mark ] = ICON::get_icon( ICON::CHECK );
+        art->show_updateicon( false );
     }
     // キャッシュ無し、新着
     else if( art->get_hour() < CONFIG::get_newthread_hour() ){
@@ -1423,6 +1502,7 @@ bool BoardView::slot_button_press( GdkEventButton* event )
     get_control().MG_wheel_start( event );
 
     // ダブルクリック
+    // button_release_eventでは event->type に必ず GDK_BUTTON_RELEASE が入る
     m_dblclick = false;
     if( event->type == GDK_2BUTTON_PRESS ) m_dblclick = true; 
 
@@ -1524,9 +1604,9 @@ bool BoardView::slot_motion_notify( GdkEventMotion* event )
     if( m_treeview.get_path_at_pos( x, y, path, column, cell_x, cell_y ) ){
 
         m_treeview.set_tooltip_min_width( column->get_width() );
-        if( column->get_title() == COLUMN_TITLE_NAME ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_subject ) );
-        else if( column->get_title() == COLUMN_TITLE_SINCE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_since ) );
-        else if( column->get_title() == COLUMN_TITLE_WRITE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_write ) );
+        if( column->get_title() == ITEM_NAME_NAME ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_subject ) );
+        else if( column->get_title() == ITEM_NAME_SINCE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_since ) );
+        else if( column->get_title() == ITEM_NAME_LASTWRITE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_write ) );
         else m_treeview.set_str_tooltip( std::string() );
     }
 
@@ -1742,6 +1822,21 @@ void BoardView::slot_copy_title_url()
 }
 
 
+//
+// 全選択
+//
+void BoardView::slot_select_all()
+{
+    SKELETON::MsgDiag mdiag( NULL, "全ての行を選択しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+    mdiag.set_default_response( Gtk::RESPONSE_NO );
+    if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+
+    Gtk::TreeModel::Children child = m_liststore->children();
+    Gtk::TreeModel::Children::iterator it = child.begin();
+    for( ; it != child.end() ; ++it ) m_treeview.get_selection()->select( *it );
+}
+
+
 //
 // ポップアップメニューでブラウザで開くを選択
 //
@@ -1815,19 +1910,16 @@ std::string BoardView::path2daturl( const Gtk::TreePath& path )
 //
 bool BoardView::drawout()
 {
-    if( m_toolbar.m_entry_search.completion() ) return false;
+    if( ! get_boardtoolbar() ) return false;
 
     int hit = 0;
     bool reset = false;
 
-    std::string query = m_toolbar.m_entry_search.get_text();
+    std::string query = get_boardtoolbar()->m_entry_search.get_text();
 
     // 空の時はリセット
     if( query.empty() ) reset = true;
 
-    if( m_pre_query == query ) return false;
-    m_pre_query = query;
-    
 #ifdef _DEBUG
     std::cout << "BoardView::drawout query = " <<  query << std::endl;
 #endif
@@ -1838,13 +1930,16 @@ bool BoardView::drawout()
     JDLIB::Regex regex;
     Gtk::TreeModel::Children child = m_liststore->children();
     Gtk::TreeModel::Children::iterator it = child.begin();
+
+    if ( ! reset ) regex.compile( query, true, true, true );
+
     for( ; it != child.end() ; ++it ){
 
         Gtk::TreeModel::Row row = *( it );
         Glib::ustring subject = row[ m_columns.m_col_subject ];
 
         if( reset ) row[ m_columns.m_col_drawbg ] = false;
-        else if( regex.exec( query, subject, 0, true, true, true ) ){
+        else if( regex.exec( subject, 0 ) ){
             row[ m_columns.m_col_drawbg ] = true;
             ++hit;
 
@@ -1856,34 +1951,46 @@ bool BoardView::drawout()
         else row[ m_columns.m_col_drawbg ] = false;
     }
 
-    if( reset || hit ) redraw_view();
+    redraw_view();
 
-    if( reset ){
-        focus_view();
-        CORE::core_set_command( "set_mginfo", "", "" );
-    }
-    else if( ! hit ) CORE::core_set_command( "set_mginfo", "", "検索結果： ヒット無し" );
-    else{
-        focus_view();
-        CORE::core_set_command( "set_mginfo", "", "検索結果： " + MISC::itostr( hit ) + "件" );
-    }
+    if( reset ) CORE::core_set_command( "set_info", "", "" );
+    else if( ! hit ) CORE::core_set_command( "set_info", "", "検索結果： ヒット無し" );
+    else CORE::core_set_command( "set_info", "", "検索結果： " + MISC::itostr( hit ) + "件" );
 
     return true;
 }
 
 
 
+//
+// 検索ボックスの文字列が変わった
+//
+void BoardView::slot_changed_search()
+{
+    if( CONFIG::get_inc_search_board() ){
+        drawout();
+        m_pre_query = std::string();
+    }
+}
+
+
 //
 // 検索移動
 //
 void BoardView::slot_active_search()
 {
-    if( m_toolbar.m_entry_search.completion() ) return;
+    if( ! get_boardtoolbar() ) return;
+    if( get_boardtoolbar()->m_entry_search.completion() ) return;
 
-    if( drawout() ) return;
+    std::string query = get_boardtoolbar()->m_entry_search.get_text();
+    if( m_pre_query != query ){
+        drawout();
+        focus_view();
+        m_pre_query = query;
+        return;
+    }
 
     focus_view();
-    std::string query = m_toolbar.m_entry_search.get_text();
     if( query.empty() ) return;
    
     Gtk::TreePath path = m_treeview.get_current_path();;
@@ -1947,13 +2054,14 @@ void BoardView::slot_push_down_search()
 }
 
 
-// キャッシュ検索
-void BoardView::slot_search_cache()
+// キャッシュ内のログ検索
+void BoardView::search_cache()
 {
-    if( m_toolbar.m_entry_search.completion() ) return;
+    if( ! get_boardtoolbar() ) return;
+    if( get_boardtoolbar()->m_entry_search.completion() ) return;
 
-    std::string query = m_toolbar.m_entry_search.get_text();
-    CORE::core_set_command( "open_article_searchcache", get_url() , query, "false" );
+    std::string query = get_boardtoolbar()->m_entry_search.get_text();
+    CORE::core_set_command( "open_article_searchlog", get_url() , query );
 }
 
 
@@ -1963,16 +2071,16 @@ void BoardView::slot_search_cache()
 void BoardView::slot_entry_operate( int controlid )
 {
     if( controlid == CONTROL::Cancel ) focus_view();
-    else if( controlid == CONTROL::SearchCache ) slot_search_cache();
+    else if( controlid == CONTROL::SearchCache ) search_cache();
 }
 
 
 //
 // 板プロパティ表示
 //
-void BoardView::slot_push_preferences()
+void BoardView::show_preference()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARD, get_url() );
+    SKELETON::PrefDiag* pref =  CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARD, get_url() );
     pref->run();
     delete pref;
 }
@@ -2025,7 +2133,9 @@ void BoardView::slot_abone_thread()
     // 板の再描画も行われる
     std::list< std::string > words = DBTREE::get_abone_list_word_thread( get_url() );
     std::list< std::string > regexs = DBTREE::get_abone_list_regex_thread( get_url() );
-    DBTREE::reset_abone_thread( get_url(), threads, words, regexs );
+    const int number = DBTREE::get_abone_number_thread( get_url() );
+    const int hour = DBTREE::get_abone_hour_thread( get_url() );
+    DBTREE::reset_abone_thread( get_url(), threads, words, regexs, number, hour );
 }
 
 
