@@ -78,9 +78,9 @@ const bool ConfigItems::load()
 #endif
 
     // 前回開いたviewを復元するか
-    restore_board = cf.get_option( "restore_board", false );
-    restore_article = cf.get_option( "restore_article", false );
-    restore_image = cf.get_option( "restore_image", false );
+    restore_board = cf.get_option( "restore_board", CONF_RESTORE_BOARD );
+    restore_article = cf.get_option( "restore_article", CONF_RESTORE_ARTICLE );
+    restore_image = cf.get_option( "restore_image", CONF_RESTORE_IMAGE );
 
     std::string defaultfont = get_default_font();
 
@@ -91,7 +91,7 @@ const bool ConfigItems::load()
     fontname[ FONT_POPUP ] = cf.get_option( "fontname_popup", defaultfont + " " + std::string( CONF_FONTSIZE_POPUP ) );
 
     // スレ一覧のフォント
-    fontname[ FONT_BBS ] = cf.get_option( "fontname_bbs", defaultfont + " " + std::string(CONF_FONTSIZE_TREE ) );
+    fontname[ FONT_BBS ] = cf.get_option( "fontname_bbs", defaultfont + " " + std::string( CONF_FONTSIZE_TREE ) );
 
     // 板一覧のフォント
     fontname[ FONT_BOARD ] = cf.get_option( "fontname_board", fontname[ FONT_BBS ] );
@@ -99,40 +99,43 @@ const bool ConfigItems::load()
     // 書き込みウィンドウのフォント
     fontname[ FONT_MESSAGE ] = cf.get_option( "fontname_message", fontname[ FONT_MAIN ] );
 
-    // レスを参照するときに前に付ける文字
-    ref_prefix = cf.get_option( "ref_prefix", ">" );
+    // Gtk::Entryのデフォルトフォント
+    fontname[ FONT_ENTRY_DEFAULT ] = MISC::get_entry_font();
 
-    // ref_prefix の後のスペースの数
+    // レスを参照するときに前に付ける文字
+    ref_prefix = cf.get_option( "ref_prefix", CONF_REF_PREFIX );
+
+    // 参照文字( CONF_REF_PREFIX ) の後のスペースの数
     // JDLIB::ConfLoader の中で MISC::remove_space() が呼ばれて空白が消えるので別設定とした
-    ref_prefix_space = cf.get_option( "ref_prefix_space", 1 );
+    ref_prefix_space = cf.get_option( "ref_prefix_space", CONF_REF_PREFIX_SPACE );
     for( int i = 0; i < ref_prefix_space; ++i ) ref_prefix += " ";
 
     // キャッシュのルートディレクトリ(旧バージョンとの互換のため残している)
-    path_cacheroot = cf.get_option( "path_cacheroot", "~/.jd/" );
+    path_cacheroot = cf.get_option( "path_cacheroot", CONF_PATH_CACHEROOT );
 
     // 読み込み用プロクシとポート番号
-    use_proxy_for2ch = cf.get_option( "use_proxy_for2ch", 0 );
+    use_proxy_for2ch = cf.get_option( "use_proxy_for2ch", CONF_USE_PROXY_FOR2CH );
     proxy_for2ch = cf.get_option( "proxy_for2ch", "" );
-    proxy_port_for2ch = cf.get_option( "proxy_port_for2ch", 8080 );
+    proxy_port_for2ch = cf.get_option( "proxy_port_for2ch", CONF_PROXY_PORT_FOR2CH );
 
     // 書き込み用プロクシとポート番号
-    use_proxy_for2ch_w = cf.get_option( "use_proxy_for2ch_w", 0 );
+    use_proxy_for2ch_w = cf.get_option( "use_proxy_for2ch_w", CONF_USE_PROXY_FOR2CH_W );
     proxy_for2ch_w = cf.get_option( "proxy_for2ch_w", "" );
-    proxy_port_for2ch_w = cf.get_option( "proxy_port_for2ch_w", 8080 );
+    proxy_port_for2ch_w = cf.get_option( "proxy_port_for2ch_w", CONF_PROXY_PORT_FOR2CH_W );
 
     // 2chの外にアクセスするときのプロクシとポート番号
-    use_proxy_for_data = cf.get_option( "use_proxy_for_data", 0 );
+    use_proxy_for_data = cf.get_option( "use_proxy_for_data", CONF_USE_PROXY_FOR_DATA );
     proxy_for_data = cf.get_option( "proxy_for_data", "" );
-    proxy_port_for_data = cf.get_option( "proxy_port_for_data", 8080 );
+    proxy_port_for_data = cf.get_option( "proxy_port_for_data", CONF_PROXY_PORT_FOR_DATA );
 
     // 2ch にアクセスするときのエージェント名
-    agent_for2ch = cf.get_option( "agent_for2ch", "Monazilla/1.00 JD" );
+    agent_for2ch = cf.get_option( "agent_for2ch", AGENT_FOR2CH );
 
     // 2ch外にアクセスするときのエージェント名
-    agent_for_data = cf.get_option( "agent_for_data", "Mozilla/5.0 (Windows; U; Windows NT 5.0; ja; rv:1.8) Gecko/20051111 Firefox/1.5" );
+    agent_for_data = cf.get_option( "agent_for_data", AGENT_FOR_DATA );
 
     // 2ch にログインするときのX-2ch-UA
-    x_2ch_ua = cf.get_option( "x_2ch_ua", "Navigator for 2ch 1.7.5" );
+    x_2ch_ua = cf.get_option( "x_2ch_ua", CONF_X_2CH_UA );
 
     // ローダのバッファサイズ
     loader_bufsize = cf.get_option( "loader_bufsize", CONF_LOADER_BUFSIZE );
@@ -141,29 +144,33 @@ const bool ConfigItems::load()
     loader_timeout = cf.get_option( "loader_timeout", CONF_LOADER_TIMEOUT );
     loader_timeout_post = cf.get_option( "loader_timeout_post", CONF_LOADER_TIMEOUT_POST ); // ポスト
     loader_timeout_img = cf.get_option( "loader_timeout_img", CONF_LOADER_TIMEOUT_IMG ); // 画像
+    loader_timeout_checkupdate = cf.get_option( "loader_timeout_checkupdate", CONF_LOADER_TIMEOUT_CHECKUPDATE ); // 更新チェック
 
     // ipv6使用
     use_ipv6 = cf.get_option( "use_ipv6", CONF_USE_IPV6 );
 
     // ブラウザ設定ダイアログのコンボボックスの番号
-    browsercombo_id = cf.get_option( "brownsercombo_id", CONF_BROWSER_NO );
+    browsercombo_id = cf.get_option( "browsercombo_id", CONF_BROWSER_NO );
 
     // リンクをクリックしたときに実行するコマンド
     command_openurl = cf.get_option( "command_openurl", CORE::get_browser_name( CONF_BROWSER_NO ) );
 
     // レス番号の上にマウスオーバーしたときに参照ポップアップ表示する
-    refpopup_by_mo = cf.get_option( "refpopup_by_mo", false );
+    refpopup_by_mo = cf.get_option( "refpopup_by_mo", CONF_REFPOPUP_BY_MO );
 
     // 名前の上にマウスオーバーしたときにポップアップ表示する
-    namepopup_by_mo = cf.get_option( "namepopup_by_mo", false );
+    namepopup_by_mo = cf.get_option( "namepopup_by_mo", CONF_NAMEPOPUP_BY_MO );
 
     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
-    idpopup_by_mo = cf.get_option( "idpopup_by_mo", false );
+    idpopup_by_mo = cf.get_option( "idpopup_by_mo", CONF_IDPOPUP_BY_MO );
 
     // 画像ポップアップサイズ
     imgpopup_width = cf.get_option( "imgpopup_width", CONF_IMGPOPUP_WIDTH );
     imgpopup_height = cf.get_option( "imgpopup_height", CONF_IMGPOPUP_HEIGHT );
 
+    // 画像ポップアップを使用する
+    use_image_popup = cf.get_option( "use_image_popup", CONF_USE_IMAGE_POPUP );
+
     // 画像ビューを使用する
     use_image_view = cf.get_option( "use_image_view", CONF_USE_IMAGE_VIEW );
 
@@ -179,9 +186,15 @@ const bool ConfigItems::load()
     // 画像キャッシュ削除の日数
     del_img_day = cf.get_option( "del_img_day", CONF_DEL_IMG_DAY );
 
-    // ダウンロードする画像の最大サイズ(Mbyte)
+    // 画像あぼーん削除の日数
+    del_imgabone_day = cf.get_option( "del_imgabone_day", CONF_DEL_IMGABONE_DAY );
+
+    // ダウンロードする画像の最大ファイルサイズ(Mbyte)
     max_img_size = cf.get_option( "max_img_size", CONF_MAX_IMG_SIZE );
 
+    // 画像の最大サイズ(Mピクセル)
+    max_img_pixel = cf.get_option( "max_img_pixel", CONF_MAX_IMG_PIXEL );
+
     // JD ホームページのアドレス
     url_jdhp = cf.get_option( "url_jdhp", CONF_JDHP );
 
@@ -194,6 +207,16 @@ const bool ConfigItems::load()
     // bbsmenu.html内にあるリンクは全て板とみなす
     use_link_as_board = cf.get_option( "use_link_as_board", CONF_LINK_AS_BOARD );
 
+    // スレタイ検索用メニュータイトルアドレス
+    menu_search_title = cf.get_option( "menu_search_title", CONF_MENU_SEARCH_TITLE );
+    url_search_title = cf.get_option( "url_search_title", CONF_URL_SEARCH_TITLE );
+
+    // スレタイ検索用正規表現
+    regex_search_title = cf.get_option( "regex_search_title", CONF_REGEX_SEARCH_TITLE );
+
+    // web検索用メニュータイトルアドレス
+    menu_search_web = cf.get_option( "menu_search_web", CONF_MENU_SEARCH_WEB );
+    url_search_web = cf.get_option( "url_search_web", CONF_URL_SEARCH_WEB );
 
     /////////
     // 色
@@ -237,6 +260,9 @@ const bool ConfigItems::load()
     // メッセージビュー(選択範囲)の文字色
     str_color[ COLOR_CHAR_MESSAGE_SELECTION ] = cf.get_option( "cl_char_message_selection", CONF_COLOR_CHAR_MESSAGE_SELECTION );
 
+    // Gtk::Entryのデフォルトの文字色
+    str_color[ COLOR_CHAR_ENTRY_DEFAULT ] = MISC::get_entry_color_text();
+
     // 画像(キャッシュ無)の色
     str_color[ COLOR_IMG_NOCACHE ] = cf.get_option( "cl_img_nocache", CONF_COLOR_IMG_NOCACHE );
 
@@ -270,6 +296,9 @@ const bool ConfigItems::load()
     // メッセージビューの選択色
     str_color[ COLOR_BACK_MESSAGE_SELECTION ] = cf.get_option( "cl_back_message_selection", CONF_COLOR_BACK_MESSAGE_SELECTION );
 
+    // Gtk::Entryのデフォルトの背景色
+    str_color[ COLOR_BACK_ENTRY_DEFAULT ] = MISC::get_entry_color_base();
+
     // 新着セパレータ
     str_color[ COLOR_SEPARATOR_NEW ] = cf.get_option( "cl_sepa_new", CONF_COLOR_SEPARATOR_NEW );
 
@@ -295,17 +324,20 @@ const bool ConfigItems::load()
 
 
     // ツリービューでgtkrcの設定を使用するか
-    use_tree_gtkrc = cf.get_option( "use_tree_gtkrc", false );
+    use_tree_gtkrc = cf.get_option( "use_tree_gtkrc", CONF_USE_TREE_GTKRC );
 
     // ツリービューの行間スペース
     tree_ypad = cf.get_option( "tree_ypad", CONF_TREE_YPAD );
 
-    // boardビューで古いスレも表示
-    show_oldarticle = cf.get_option( "show_oldarticle", false );
+    // スレ一覧で古いスレも表示
+    show_oldarticle = cf.get_option( "show_oldarticle", CONF_SHOW_OLDARTICLE );
 
     // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
     newthread_hour = cf.get_option( "newthread_hour", CONF_NEWTHREAD_HOUR );
 
+    // スレ一覧でインクリメント検索をする
+    inc_search_board = cf.get_option( "inc_search_board", CONF_INC_SEARCH_BOARD );
+
     // ツリービューのスクロール量(行数)
     tree_scroll_size = cf.get_option( "tree_scroll_size", CONF_TREE_SCROLL_SIZE );
 
@@ -315,17 +347,23 @@ const bool ConfigItems::load()
     // スレビューのスクロール量(キー上下)
     key_scroll_size = cf.get_option( "key_scroll_size", CONF_KEY_SCROLL_SIZE );
 
-    // 板一覧でカテゴリを常にひとつだけ開く
-    open_one_category = cf.get_option( "open_one_category", false );
+    // スレビューでリロード後に一番下までスクロール
+    jump_after_reload = cf.get_option( "jump_after_reload", CONF_JUMP_AFTER_RELOAD );
 
-    // 書き込み時に書き込み確認ダイアログを出すかどうか
-    always_write_ok = cf.get_option( "always_write_ok", false );
+    // 板一覧でカテゴリを常にひとつだけ開く
+    open_one_category = cf.get_option( "open_one_category", CONF_OPEN_ONE_CATEGORY );
+
+    // 書き込み時に書き込み確認ダイアログを出さない
+    always_write_ok = cf.get_option( "always_write_ok", CONF_ALWAYS_WRITE_OK );
 
     // 書き込みログを保存
-    save_postlog = cf.get_option( "save_postlog", false );
+    save_postlog = cf.get_option( "save_postlog", CONF_SAVE_POSTLOG );
 
     // 「書き込み中」のダイアログを表示しない
-    hide_writing_dialog = cf.get_option( "hide_writing_dialog", false );
+    hide_writing_dialog = cf.get_option( "hide_writing_dialog", CONF_HIDE_WRITING_DIALOG );
+
+    // 非アクティブ時に書き込みビューを折りたたむ
+    fold_message = cf.get_option( "fold_message", CONF_FOLD_MESSAGE );
 
     // ポップアップとカーソルの間のマージン
     margin_popup = cf.get_option( "margin_popup", CONF_MARGIN_POPUP );
@@ -346,40 +384,53 @@ const bool ConfigItems::load()
     instruct_popup = cf.get_option( "instruct_popup", CONF_INSTRUCT_POPUP );    
 
     // スレビューを開いたときにスレ一覧との切り替え方法を説明する
-    instruct_tglart = cf.get_option( "instruct_tglart", true );
+    instruct_tglart = cf.get_option( "instruct_tglart", CONF_INSTRUCT_TGLART );
     instruct_tglart_end = false;
 
     // 画像ビューを開いたときにスレビューとの切り替え方法を説明する
-    instruct_tglimg = cf.get_option( "instruct_tglimg", true );
+    instruct_tglimg = cf.get_option( "instruct_tglimg", CONF_INSTRUCT_TGLIMG );
     instruct_tglimg_end = false;
     
-    // スレ表示の行間調整
-    adjust_underline_pos = cf.get_option( "adjust_underline_pos", 1.0 );
-    adjust_line_space = cf.get_option( "adjust_line_space", 1.0 );
+    // 下線位置
+    adjust_underline_pos = cf.get_option( "adjust_underline_pos", ( double )CONF_ADJUST_UNDERLINE_POS );
+
+    // 行間スペース
+    adjust_line_space = cf.get_option( "adjust_line_space", ( double )CONF_ADJUST_LINE_SPACE );
 
     // リンク下線を表示
-    draw_underline = cf.get_option( "draw_underline", true );
+    draw_underline = cf.get_option( "draw_underline", CONF_DRAW_UNDERLINE );
 
     // スレビューで文字幅の近似を厳密にする
-    strict_char_width = cf.get_option( "strict_char_width", false );
+    strict_char_width = cf.get_option( "strict_char_width", CONF_STRICT_CHAR_WIDTH );
+
+    // スレビューで発言数(ID)をカウントする
+    check_id = cf.get_option( "check_id", CONF_CHECK_ID );
+
+    // レス参照で色を変える回数
+    num_reference_high = cf.get_option( "num_reference_high", CONF_NUM_REFERENCE_HIGH );
+    num_reference_low = cf.get_option( "num_reference_low", CONF_NUM_REFERENCE_LOW );
+
+    // 発言数で色を変える回数
+    num_id_high = cf.get_option( "num_id_high", CONF_NUM_ID_HIGH );
+    num_id_low = cf.get_option( "num_id_low", CONF_NUM_ID_LOW );
 
     // datのパース時にURL判定を甘くする(^なども含める)
     loose_url = cf.get_option( "loose_url", CONF_LOOSE_URL );
 
     // ユーザーコマンドで選択できない項目を非表示にする
-    hide_usrcmd = cf.get_option( "hide_usrcmd", false );
+    hide_usrcmd = cf.get_option( "hide_usrcmd", CONF_HIDE_USRCMD );
 
     // 指定した数よりもユーザーコマンドが多い場合はサブメニュー化する
-    max_show_usrcmd = cf.get_option( "max_show_usrcmd", 3 );
+    max_show_usrcmd = cf.get_option( "max_show_usrcmd", CONF_MAX_SHOW_USRCMD );
 
     // スレビューで再読み込みボタンを押したときに全タブを更新する
     reload_allthreads = cf.get_option( "reload_allthreads", CONF_RELOAD_ALLTHREAD );
 
     // タブに表示する文字列の最小値
-    tab_min_str = cf.get_option( "tab_min_str", 4 );
+    tab_min_str = cf.get_option( "tab_min_str", CONF_TAB_MIN_STR );
 
     // タブにアイコンを表示するか
-    show_tab_icon = cf.get_option( "show_tab_icon", true );
+    show_tab_icon = cf.get_option( "show_tab_icon", CONF_SHOW_TAB_ICON );
 
     std::list< std::string > list_tmp;
     std::list< std::string >::iterator it_tmp;
@@ -393,6 +444,12 @@ const bool ConfigItems::load()
     str_tmp = cf.get_option( "aboneregexthread", "" );
     if( ! str_tmp.empty() ) list_abone_regex_thread = MISC::strtolist( str_tmp );
 
+    // スレ あぼーん( レス数 )
+    abone_number_thread = cf.get_option( "abone_number_thread", CONF_ABONE_NUMBER_THREAD );
+
+    // スレ あぼーん( スレ立てからの経過時間 )
+    abone_hour_thread = cf.get_option( "abone_hour_thread", CONF_ABONE_HOUR_THREAD );
+
     // あぼーん name
     str_tmp = cf.get_option( "abonename", "" );
     if( ! str_tmp.empty() ) list_abone_name = MISC::strtolist( str_tmp );
@@ -444,6 +501,11 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "url_login2ch", url_login2ch );
     cf.update( "url_bbsmenu", url_bbsmenu );
     cf.update( "use_link_as_board", use_link_as_board );
+    cf.update( "menu_search_title", menu_search_title );
+    cf.update( "url_search_title", url_search_title );
+    cf.update( "regex_search_title", regex_search_title );
+    cf.update( "menu_search_web", menu_search_web );
+    cf.update( "url_search_web", url_search_web );
 
     cf.update( "fontname_main", fontname[ FONT_MAIN ] );
     cf.update( "fontname_popup", fontname[ FONT_POPUP ] );
@@ -478,11 +540,12 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "loader_timeout", loader_timeout );
     cf.update( "loader_timeout_post", loader_timeout_post );
     cf.update( "loader_timeout_img", loader_timeout_img );
+    cf.update( "loader_timeout_checkupdate", loader_timeout_checkupdate );
 
     cf.update( "use_ipv6", use_ipv6 );
 
     cf.update( "command_openurl", command_openurl );
-    cf.update( "brownsercombo_id", browsercombo_id );
+    cf.update( "browsercombo_id", browsercombo_id );
 
     cf.update( "refpopup_by_mo", refpopup_by_mo );
     cf.update( "namepopup_by_mo", namepopup_by_mo );
@@ -490,12 +553,15 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "imgpopup_width", imgpopup_width );
     cf.update( "imgpopup_height", imgpopup_height );
+    cf.update( "use_image_popup", use_image_popup );
     cf.update( "use_image_view", use_image_view );
     cf.update( "use_inline_image", use_inline_image );
     cf.update( "use_mosaic", use_mosaic );
     cf.update( "zoom_to_fit", zoom_to_fit );
     cf.update( "del_img_day", del_img_day );
+    cf.update( "del_imgabone_day", del_imgabone_day );
     cf.update( "max_img_size", max_img_size );
+    cf.update( "max_img_pixel", max_img_pixel );
 
     cf.update( "cl_char", str_color[ COLOR_CHAR ] );
     cf.update( "cl_char_name", str_color[ COLOR_CHAR_NAME ] );
@@ -535,14 +601,17 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "show_oldarticle", show_oldarticle );
     cf.update( "newthread_hour", newthread_hour );
+    cf.update( "inc_search_board", inc_search_board );
 
     cf.update( "tree_scroll_size", tree_scroll_size );
     cf.update( "scroll_size", scroll_size );
     cf.update( "key_scroll_size", key_scroll_size );
+    cf.update( "jump_after_reload", jump_after_reload );
     cf.update( "open_one_category", open_one_category );
     cf.update( "always_write_ok", always_write_ok );
     cf.update( "save_postlog", save_postlog );
     cf.update( "hide_writing_dialog", hide_writing_dialog );
+    cf.update( "fold_message", fold_message );
     cf.update( "margin_popup", margin_popup );
     cf.update( "margin_imgpopup", margin_imgpopup );
     cf.update( "mouse_radius", mouse_radius );
@@ -557,6 +626,13 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "draw_underline", draw_underline );
     cf.update( "strict_char_width", strict_char_width );
+    cf.update( "check_id", check_id );
+
+    cf.update( "num_reference_high", num_reference_high );
+    cf.update( "num_reference_low", num_reference_low );
+    cf.update( "num_id_high", num_id_high );
+    cf.update( "num_id_low", num_id_low );
+
     cf.update( "loose_url", loose_url );
 
     cf.update( "hide_usrcmd", hide_usrcmd );
@@ -574,6 +650,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "abonewordthread", str_abone_word_thread );
     cf.update( "aboneregexthread", str_abone_regex_thread );
 
+    cf.update( "abone_number_thread", abone_number_thread );
+    cf.update( "abone_hour_thread", abone_hour_thread );
+
     // あぼーん情報
     std::string str_abone_name = MISC::listtostr( list_abone_name );
     std::string str_abone_word = MISC::listtostr( list_abone_word );
