@@ -45,14 +45,19 @@ void MouseKeyConf::save_conf( const std::string& savefile )
         std::string motion;
         std::vector< MouseKeyItem* >::iterator it = m_vec_items.begin();
         for( ; it != m_vec_items.end(); ++it ){
-            if( (*it)->get_id() == id ){
+            if( (*it)->get_id() == id && (*it)->get_save() ){
                 name = (*it)->get_name();
                 if( !motion.empty() ) motion += " ";
                 motion += (*it)->get_str_motion();
             }
         }
 
-        if( !name.empty() && !motion.empty() ) cf.update( name, motion );
+        if( !name.empty() ){
+#ifdef _DEBUG
+            std::cout << name << " = " << motion << std::endl;
+#endif
+            cf.update( name, motion );
+        }
     }
 
     cf.save();
@@ -145,8 +150,10 @@ int MouseKeyConf::get_mode( const int& id )
     if( id < CONTROL::BBSLISTMOTION_END ) return CONTROL::MODE_BBSLIST;
     if( id < CONTROL::BOARDMOTION_END ) return CONTROL::MODE_BOARD;
     if( id < CONTROL::ARTICLEMOTION_END ) return CONTROL::MODE_ARTICLE;
-    if( id < CONTROL::IMAGEMOTION_END ) return CONTROL::MODE_IMAGE;
+    if( id < CONTROL::IMAGEICONMOTION_END ) return CONTROL::MODE_IMAGEICON;
+    if( id < CONTROL::IMAGEVIEWMOTION_END ) return CONTROL::MODE_IMAGEVIEW;
     if( id < CONTROL::MESSAGEMOTION_END ) return CONTROL::MODE_MESSAGE;
+    if( id < CONTROL::EDITMOTION_END ) return CONTROL::MODE_EDIT;
 
     return CONTROL::MODE_ERROR;
 }
