@@ -51,9 +51,9 @@ namespace MESSAGE
     class MessageAdmin;
 }
 
-
 namespace CORE
 {
+    class MainToolBar;
     class DND_Manager;
     class HistoryMenuThread;
     class HistoryMenuBoard;
@@ -83,18 +83,7 @@ namespace CORE
         SKELETON::JDVPaned m_vpaned_message; // 埋め込み書き込みビュー用
 
         // ツールバー
-        Gtk::ScrolledWindow m_toolbar;
-        Gtk::Tooltips m_tooltip;
-        Gtk::HBox m_toolbar_hbox;
-        Gtk::Entry m_entry_url;
-        SKELETON::ImgButton m_button_go;
-        SKELETON::ImgToggleButton m_button_bbslist;
-        SKELETON::ImgToggleButton m_button_favorite;
-        SKELETON::ImgToggleButton m_button_board;
-        SKELETON::ImgToggleButton m_button_thread;
-        SKELETON::ImgToggleButton m_button_image;
-        Gtk::VSeparator m_vspr_toolbar_1;
-        Gtk::VSeparator m_vspr_toolbar_2;
+        MainToolBar* m_toolbar;
 
         // タイトルに表示する文字列
         // set_maintitle() 参照
@@ -109,15 +98,9 @@ namespace CORE
         HistoryMenuClose* m_histmenu_close;
         bool m_enable_menuslot;
 
-        // 起動中
-        bool m_boot;
-
         // 初期設定中
         bool m_init;
 
-        // 終了中
-        bool m_quit;
-
     public:
 
         Core( WinMain& win_main );
@@ -153,7 +136,7 @@ namespace CORE
 
         void slot_toggle_save_postlog();
         void slot_toggle_use_mosaic();
-        void slot_toggle_use_imgview();
+        void slot_toggle_use_imgpopup();
         void slot_toggle_use_inlineimg();
         void slot_delete_all_images();
 
@@ -177,7 +160,13 @@ namespace CORE
         void slot_setup_fontcolor();
         void slot_setup_proxy();
         void slot_setup_passwd();
+        void slot_toggle_ipv6();
+        void slot_setup_mainitem();
+        void slot_setup_sidebaritem();
+        void slot_setup_boarditemcolumn();
         void slot_setup_boarditem();
+        void slot_setup_articleitem();
+        void slot_setup_msgitem();
         void slot_board_pref();
         void slot_article_pref();
         void slot_image_pref();
@@ -198,10 +187,12 @@ namespace CORE
         void slot_save_favorite();
         void slot_toggle_online();
         void slot_toggle_login2ch();
+        void slot_toggle_loginbe();
         void toggle_menubar();
         void toggle_sidebar();
         void slot_search_cache_board();
         void slot_search_cache();
+        void slot_search_title();
         void slot_show_hide_leftpane( int mode );
         void slot_toggle_toolbarpos( int pos );
         void slot_toggle_toolbarbbslist();
@@ -212,8 +203,9 @@ namespace CORE
         void slot_toggle_2pane();
         void slot_toggle_3pane();
         void slot_toggle_v3pane();
-        void slot_toggle_embedded_mes();
-        void slot_toggle_embedded_img();
+        void slot_toggle_winmsg();
+        void slot_toggle_embmsg();
+        void slot_toggle_imgview( const int mode );
         void slot_toggle_oldarticle();
         void slot_toggle_tabbutton();
         void slot_toggle_popupwarpmode();
