@@ -768,7 +768,7 @@ void BoardBase::receive_finish()
     std::cout << "size = " << m_lng_rawdata << std::endl;
 #endif
 
-    // 移転チェック
+    // url_boardbase をロードして移転が起きたかチェック
     if( m_read_url_boardbase ){
 
 #ifdef _DEBUG
@@ -788,17 +788,22 @@ void BoardBase::receive_finish()
             if( regex.exec( query, m_rawdata ) ){
 
                 std::string new_url = regex.str( 1 );
-                std::string msg = new_url + " に移転しました。\n\nデータベースを更新しますか？";
+                std::string msg = "「" + get_name() + "」は\n\n" + new_url + " に移転しました。\n\nデータベースを更新しますか？";
 
-                SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-                mdiag.set_default_response( Gtk::RESPONSE_OK );
-                if( mdiag.run() == Gtk::RESPONSE_OK ){
+                SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+                mdiag.set_default_response( Gtk::RESPONSE_YES );
+                if( mdiag.run() == Gtk::RESPONSE_YES ){
 
                     DBTREE::update_board( new_url, get_name() );
                     CORE::core_set_command( "open_board", url_subject() );
                 }
             }
         }
+        else{
+            SKELETON::MsgDiag mdiag( NULL, "移転しました\n\n板リストを更新しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            mdiag.set_default_response( Gtk::RESPONSE_YES );
+            if( mdiag.run() == Gtk::RESPONSE_YES ) CORE::core_set_command( "reload_bbsmenu" );
+        }
 
         clear();
         return;
@@ -811,14 +816,13 @@ void BoardBase::receive_finish()
 
         m_lng_rawdata = 0;
 
-        // 移転した場合bbsmenuを更新
+        // リダイレクトの場合は移転確認
         if( get_code() == HTTP_REDIRECT ){
 
-            SKELETON::MsgDiag mdiag( NULL, "移転しました\n\n板リストを更新しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-            mdiag.set_default_response( Gtk::RESPONSE_OK );
-            if( mdiag.run() == Gtk::RESPONSE_OK ) CORE::core_set_command( "reload_bbsmenu" );
-
             set_date_modified( std::string() );
+
+            if( start_checkking_if_board_moved() ) return;
+
             CORE::core_set_command( "update_board", url_subject() );
             clear();
             return;
@@ -854,23 +858,7 @@ void BoardBase::receive_finish()
 
         // 移転した可能性があるので url_boardbase をロードして解析
         if( SESSION::is_online() && get_code() == HTTP_OK ){
-
-#ifdef _DEBUG
-            std::cout << "reload " << url_boardbase() << std::endl;
-#endif
-            JDLIB::LOADERDATA data;    
-            data.url = url_boardbase();
-            data.agent = CONFIG::get_agent_for_data();
-            if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
-            else data.host_proxy = std::string();
-            data.port_proxy = CONFIG::get_proxy_port_for_data();
-            data.size_buf = CONFIG::get_loader_bufsize();
-            data.timeout = CONFIG::get_loader_timeout_img();
-
-            if( start_load( data ) ){
-                m_read_url_boardbase = true;
-                return;
-            }
+            if( start_checkking_if_board_moved() ) return;
         }
 
         CORE::core_set_command( "update_board", url_subject() );
@@ -888,6 +876,9 @@ void BoardBase::receive_finish()
     // データベース更新
     // subject.txtを解析して現行スレだけリスト(m_list_subject)に加える
 
+    // キャッシュにあるレスをデータベースに登録
+    append_all_article_in_cache();
+
     // 一度全てのarticleをdat落ち状態にして subject.txt に
     // 含まれているものだけ parse_subject()の中で通常状態にする
     std::list< ArticleBase* >::iterator it;
@@ -923,7 +914,7 @@ void BoardBase::receive_finish()
                     // info 読み込み
                     // TODO : 数が多いとboardビューを開くまで時間がかかるのをなんとかする
 #ifdef _DEBUG
-                    std::cout << "read article_info << " << ( *it )->get_url() << std::endl;
+                    std::cout << "read article_info : " << ( *it )->get_url() << std::endl;
 #endif                
                     ( *it )->read_info();
 
@@ -989,6 +980,34 @@ void BoardBase::receive_finish()
 }
 
 
+//
+// url_boardbase をロードして移転したかどうか解析開始
+//
+// 移転した場合は window.location.href が含まれるテキストがサーバから送られてくる
+//
+bool BoardBase::start_checkking_if_board_moved()
+{
+#ifdef _DEBUG
+    std::cout << "BoardBase::start_checkking_if_board_moved " << url_boardbase() << std::endl;
+#endif
+
+    JDLIB::LOADERDATA data;    
+    data.url = url_boardbase();
+    data.agent = CONFIG::get_agent_for_data();
+    if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
+    else data.host_proxy = std::string();
+    data.port_proxy = CONFIG::get_proxy_port_for_data();
+    data.size_buf = CONFIG::get_loader_bufsize();
+    data.timeout = CONFIG::get_loader_timeout_img();
+
+    if( start_load( data ) ){
+        m_read_url_boardbase = true;
+        return true;
+    }
+
+    return false;
+}
+
 
 //
 // キャッシュのディレクトリ内にあるスレのファイル名のリストを取得
@@ -1269,7 +1288,7 @@ std::list< std::string > BoardBase::search_cache( const std::string& query,
     if( empty() ) return list_out;
 
     // キャッシュにあるレスをデータベースに登録
-    if( m_list_article.size() == 0 ) append_all_article_in_cache();
+    append_all_article_in_cache();
     if( m_list_article.size() == 0 ) return list_out;
 
     std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
