@@ -60,6 +60,7 @@ NodeTreeBase::NodeTreeBase( const std::string url, const std::string& modified )
       m_heap( SIZE_OF_HEAP ),
       m_buffer_lines( 0 ),
       m_parsed_text( 0 ),
+      m_check_update( false ),
       m_fout ( 0 )
 {
     set_date_modified( modified );
@@ -76,6 +77,14 @@ NodeTreeBase::NodeTreeBase( const std::string url, const std::string& modified )
 
     m_default_noname = DBTREE::default_noname( m_url );
 
+    // 参照で色を変える回数
+    m_num_reference[ LINK_HIGH ] = CONFIG::get_num_reference_high();
+    m_num_reference[ LINK_LOW ] = CONFIG::get_num_reference_low();
+
+    // 発言数で色を変える回数
+    m_num_id[ LINK_HIGH ] = CONFIG::get_num_id_high();
+    m_num_id[ LINK_LOW ] = CONFIG::get_num_id_low();
+
 #ifdef _DEBUG
     std::cout << "NodeTreeBase::NodeTreeBase url = " << m_url << " modified = " << date_modified()
               << " noname = " << m_default_noname << std::endl;
@@ -171,6 +180,20 @@ NODE* NodeTreeBase::res_header( int number )
 //
 int NodeTreeBase::get_num_id_name( const std::string& id )
 {
+    if( id.empty() ) return 0;
+
+    if( ! CONFIG::get_check_id() ){ // IDの数を数えていない場合は全て数える
+
+        int count = 0;
+        for( int i = 1; i <= m_id_header; ++i ){
+
+            if( get_id_name( i ) == id ) count++;
+        }
+        return count;
+    }
+
+    // IDの数を数えている場合
+
     for( int i = 1; i <= m_id_header; ++i ){
 
         if( get_id_name( i ) == id ) return get_num_id_name( i );
@@ -188,6 +211,9 @@ int NodeTreeBase::get_num_id_name( int number )
     NODE* head = res_header( number );
     if( ! head ) return 0;
 
+    // IDの数を数えていない場合
+    if( ! CONFIG::get_check_id() ) return get_num_id_name( get_id_name( number ) );
+
     return head->headinfo->num_id_name;
 }
 
@@ -857,6 +883,7 @@ void NodeTreeBase::load_cache()
 
             const char* data = str.data();
             size_t size = 0;
+            m_check_update = false;
             init_loading();
             while( size < str.length() ){
                 size_t size_tmp = MIN( MAXSISE_OF_LINES, str.length() - size );
@@ -888,14 +915,17 @@ void NodeTreeBase::init_loading()
 //
 // ロード開始
 //
-void NodeTreeBase::download_dat()
+void NodeTreeBase::download_dat( const bool check_update )
 {
 #ifdef _DEBUG    
-    std::cout << "NodeTreeBase::download_dat : " << m_url << std::endl;
+    std::cout << "NodeTreeBase::download_dat : " << m_url << " lng = " << m_lng_dat << std::endl
+              << "modified = " << date_modified() << " check_update = " << check_update << std::endl;
 #endif
 
     if( is_loading() ) return;
 
+    m_check_update = check_update;
+
     // オフライン
     if( ! SESSION::is_online() ){
 
@@ -913,29 +943,39 @@ void NodeTreeBase::download_dat()
 
     init_loading();
 
-    // 保存ディレクトリ作成(無ければ)
-    if( CACHE::mkdir_boardroot( m_url ) ){
+    if( ! m_check_update ){
+
+        // 保存ディレクトリ作成(無ければ)
+        if( CACHE::mkdir_boardroot( m_url ) ){
     
-        // 保存ファイルオープン
-        std::string path_cache = CACHE::path_dat( m_url );
+            // 保存ファイルオープン
+            std::string path_cache = CACHE::path_dat( m_url );
 
 #ifdef _DEBUG
-        std::cout << "open " << path_cache.c_str() << std::endl;
+            std::cout << "open " << path_cache.c_str() << std::endl;
 #endif
 
-        m_fout = fopen( path_cache.c_str(), "ab" );
-        if( m_fout == NULL ){
-            MISC::ERRMSG( "fopen failed : " + path_cache );
+            m_fout = fopen( path_cache.c_str(), "ab" );
+            if( m_fout == NULL ){
+                MISC::ERRMSG( "fopen failed : " + path_cache );
+            }
+        }
+        else{
+            MISC::ERRMSG( "could not create " + DBTREE::url_boardbase( m_url ) );
         }
-    }
-    else{
-        MISC::ERRMSG( "could not create " + DBTREE::url_boardbase( m_url ) );
     }
 
     // ロード開始
     // ロード完了したら receive_finish() が呼ばれる
     JDLIB::LOADERDATA data;
     create_loaderdata( data );
+
+    // 更新チェックの時はHEADを使う
+    if( m_check_update ){
+        data.head = true;
+        data.timeout = CONFIG::get_loader_timeout_checkupdate();
+    }
+
     if( data.url.empty() || ! start_load( data ) ){
         m_sig_finished.emit();
         clear();
@@ -961,6 +1001,8 @@ void NodeTreeBase::receive_data( const char* data, size_t size )
         return;
     }
 
+    if( m_check_update ) return;
+
     // レジューム処理
     // レジュームした時に先頭が '\n' かチェック
     // '\n'で無ければあぼーんがあったということ
@@ -1016,22 +1058,27 @@ void NodeTreeBase::receive_finish()
         MISC::ERRMSG( err.str() );
     }
 
-    // Requested Range Not Satisfiable
-    if( get_code() == HTTP_RANGE_ERR ) m_broken = true;
+    if( ! m_check_update ){
 
-    // データがロードされなかったらキャッシュを消す
-    if( get_res_number() == 0 ){
+        // Requested Range Not Satisfiable
+        if( get_code() == HTTP_RANGE_ERR ) m_broken = true;
 
-        std::string path = CACHE::path_dat( m_url );
-        if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( path.c_str() );
-        set_date_modified( std::string() );
+        // データがロードされなかったらキャッシュを消す
+        if( get_res_number() == 0 ){
+
+            std::string path = CACHE::path_dat( m_url );
+            if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( path.c_str() );
+            set_date_modified( std::string() );
+        }
+
+        // その他、何かエラーがあったらmodifiedをクリアしておく
+        if( !get_ext_err().empty() ) set_date_modified( std::string() );
     }
 
-    // その他、何かエラーがあったらmodifiedをクリアしておく
-    if( !get_ext_err().empty() ) set_date_modified( std::string() );
-
 #ifdef _DEBUG
-    std::cout << "NodeTreeBase::receive_finish lng = " << m_lng_dat << " code = " << get_code() << " " << get_str_code() << std::endl;
+    std::cout << "NodeTreeBase::receive_finish lng = " << m_lng_dat
+              << " code = " << get_code() << " " << get_str_code()
+              << " modified = " << date_modified() << std::endl;
 #endif    
     
     // 親 article クラスにシグナルを打ってツリー構造が変わったことを教える
@@ -1157,7 +1204,7 @@ const char* NodeTreeBase::add_one_dat_line( const char* datline )
         header->headinfo->block[ BLOCK_MES ] = create_block_node();
         const char str_broken[] = "ここ";
         create_linknode( str_broken, strlen( str_broken ) , PROTO_BROKEN, strlen( PROTO_BROKEN ), COLOR_CHAR_LINK, false );
-        createTextNode( "をクリックしてスレを再読み込みして下さい。", COLOR_CHAR );
+        createTextNode( "をクリックしてスレを再取得して下さい。", COLOR_CHAR );
         
         return pos;
     }
@@ -1348,14 +1395,17 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
         // BE:
         else if( str[ start_block ] == 'B' && str[ start_block + 1 ] == 'E' ){
 
+            const int strlen_of_BE = 3; // = strlen( "BE:" );
+
             // フラッシュ
             if( lng_text ) createTextNodeN( str + start, lng_text, COLOR_CHAR );
 
             // id 取得
-            lng_id_tmp = 0;
-            while( str[ start_block + lng_id_tmp ] != '-' && lng_id_tmp < lng_block ) ++lng_id_tmp;
-            lng_id_tmp -= 3;
-            memcpy( tmpid, str + start_block + 3, lng_id_tmp );
+            int lng_header = 0;
+            while( str[ start_block + lng_header ] != '-' && lng_header < lng_block ) ++lng_header;
+            lng_id_tmp = lng_header - strlen_of_BE;
+            if( str[ start_block + lng_header ] == '-' ) ++lng_header;
+            memcpy( tmpid, str + start_block + strlen_of_BE, lng_id_tmp );
             tmpid[ lng_id_tmp ] = '\0';
 
             // リンク文字作成
@@ -1363,8 +1413,8 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, int lng )
             memcpy( tmplink + sizeof( PROTO_BE ) -1, tmpid, lng_id_tmp + 1 );
 
             // リンク作成
-            create_linknode( "BE:", 3 , tmplink, strlen( tmplink ), COLOR_CHAR, false );
-            createTextNodeN( tmpid, lng_id_tmp, COLOR_CHAR);
+            create_linknode( "?", 1, tmplink, strlen( tmplink ), COLOR_CHAR, false );
+            createTextNodeN( str + start_block + lng_header, lng_block - lng_header, COLOR_CHAR);
 
             // 次のブロックへ移動
             start = start_block + lng_block;
@@ -1434,22 +1484,12 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
         // HTMLタグ
         if( *pos == '<' ){ 
 
+            bool br = false;
+
             // 改行 <br>
             if( ( *( pos + 1 ) == 'b' || *( pos + 1 ) == 'B' )
-                &&  ( *( pos + 2 ) == 'r' || *( pos + 2 ) == 'R' ) ){  
-
-                // フラッシュ
-                if( *( pos - 1 ) == ' ' ) --lng_text; // 改行前の空白を取り除く
-                createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
-
-                pos += 4;
-                
-                // 改行ノード作成
-                createBrNode();
-
-                // 改行直後と行頭の空白は全て除く
-                while( *pos == ' ' ) ++pos;
-            }
+                && ( *( pos + 2 ) == 'r' || *( pos + 2 ) == 'R' )
+                ) br = true;
 
             //  ahref == true かつ <a href=～></a>
             else if( ahref &&
@@ -1458,14 +1498,15 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
                 // フラッシュ
                 createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
 
-                while( pos < pos_end && *pos != '"' ) ++pos;
-                if( pos >= pos_end ) continue;
+                while( pos < pos_end && *pos != '=' ) ++pos;
                 ++pos;
+                if( *pos == '"' || *pos == ' ' ) ++pos;
+                if( pos >= pos_end ) continue;
 
                 const char* pos_link_start = pos;
                 int lng_link = 0;
 
-                while( pos < pos_end && *pos != '"' ){ ++pos; ++lng_link; }
+                while( pos < pos_end && ( *pos != '"' && *pos != ' ' && *pos != '>' ) ){ ++pos; ++lng_link; }
                 if( pos >= pos_end ) continue;
 
                 while( pos < pos_end && *pos != '>' ) ++pos;
@@ -1483,13 +1524,69 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
                 ++pos;
 
                 if( lng_link && lng_str ){
-                    create_linknode( pos_str_start, lng_str , pos_link_start, lng_link, COLOR_CHAR, false );
+                    create_linknode( pos_str_start, lng_str , pos_link_start, lng_link, COLOR_CHAR_LINK, false );
                 }
             }
 
             // </a>
             else if( *( pos + 1 ) == '/' && ( *( pos + 2 ) == 'a' || *( pos + 2 ) == 'A' ) && *( pos + 3 ) == '>' ) pos += 4;
 
+            // 改行にするタグ
+            else if(
+                // <p>
+                (
+                    ( *( pos + 1 ) == 'p' || *( pos + 1 ) == 'P' )
+                    && *( pos + 2 ) == '>'
+                    )
+
+                // </p>
+                || (
+                    ( *( pos + 2 ) == 'p' || *( pos + 2 ) == 'P' )
+                    && *( pos + 3 ) == '>'
+                    && *( pos + 1 ) == '/'
+                    )
+
+                // <dd>
+                || (
+                    ( *( pos + 1 ) == 'd' || *( pos + 1 ) == 'D' )
+                    && ( *( pos + 2 ) == 'd' || *( pos + 2 ) == 'D' )
+                    )
+
+                // </dl>
+                || (
+                    ( *( pos + 2 ) == 'd' || *( pos + 2 ) == 'D' )
+                    && ( *( pos + 3 ) == 'l' || *( pos + 3 ) == 'L' )
+                    && *( pos + 1 ) == '/'
+                    )
+
+                // </ul>
+                || (
+                    ( *( pos + 2 ) == 'u' || *( pos + 2 ) == 'U' )
+                    && ( *( pos + 3 ) == 'l' || *( pos + 3 ) == 'L' )
+                    && *( pos + 1 ) == '/'
+                    )
+
+                // </li>
+                || (
+                    ( *( pos + 2 ) == 'l' || *( pos + 2 ) == 'L' )
+                    && ( *( pos + 3 ) == 'i' || *( pos + 3 ) == 'I' )
+                    && *( pos + 1 ) == '/'
+                    )
+                ) br = true;
+
+            // <li>は・にする
+            else if( ( *( pos + 1 ) == 'l' || *( pos + 2 ) == 'L' )
+                     && ( *( pos + 2 ) == 'i' || *( pos + 3 ) == 'I' )
+                ){
+
+                pos += 4;
+
+                int n_in = 0;
+                int n_out = 0;
+                DBTREE::decode_char( "&#12539;", n_in, m_parsed_text + lng_text, n_out );
+                lng_text += n_out;
+            }
+
             // その他のタグは無視。タグを取り除いて中身だけを見る
             else {
 
@@ -1500,6 +1597,21 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
                 ++pos;
             }
 
+            // 改行実行
+            if( br ){
+
+                // フラッシュ
+                if( *( pos - 1 ) == ' ' ) --lng_text; // 改行前の空白を取り除く
+                createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+
+                // 改行ノード作成
+                createBrNode();
+
+                // 改行直後と行頭の空白は全て除く
+                while( *pos != '>' ) ++pos; ++pos;
+                while( *pos == ' ' ) ++pos;
+            }
+
             // forのところで++されるので--しておく
             --pos;
             continue;
@@ -1565,7 +1677,7 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
             lng_link = strlen( tmplink );
 
             // 画像リンク
-            if( DBIMG::is_loadable( tmplink, lng_link ) ){
+            if( DBIMG::get_type_ext( tmplink, lng_link ) != DBIMG::T_UNKNOWN ){
                 create_imgnode( pos, n_in, tmplink , lng_link, COLOR_IMG_NOCACHE, bold );
             }
 
@@ -1614,6 +1726,14 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
             continue;
         }
 
+        ///////////////////////
+        // LF(0x0A), CR(0x0D)
+        if( *pos == 0x0A || *pos == 0x0D ){
+
+            // 無視する
+            continue;
+        }
+
         // 連続する空白は一個にする
         while( *pos == ' ' && *( pos + 1 ) == ' ' ) ++pos;
 
@@ -1783,126 +1903,77 @@ bool NodeTreeBase::check_anchor( int mode, const char* str_in,
 //
 // 戻り値 : リンクが現れれば true
 //
-
+// 注意 : MISC::is_url_scheme() と MISC::is_url_char() の仕様に合わせる事
 //
-// Thanks to 「パッチ投稿」スレの8氏
-//
-// http://jd4linux.sourceforge.jp/cgi-bin/bbs/test/read.cgi/support/1151836078/8
-//
-
-enum
-{
-    LINKTYPE_NONE,
-
-    LINKTYPE_HTTP,
-    LINKTYPE_FTP,
-    LINKTYPE_TTP,
-    LINKTYPE_TP
-};
-
 bool NodeTreeBase::check_link( const char* str_in, int lng_in, int& n_in, char* str_link, int lng_link )
 {
     // CONFIG::get_loose_url() == true の時はRFCで規定されていない文字も含める
     const bool loose_url = CONFIG::get_loose_url();
 
     // http://, https://, ftp://, ttp(s)://, tp(s):// のチェック
-    int linktype = LINKTYPE_NONE;
+    int delim_pos = 0;
+    int linktype = MISC::is_url_scheme( str_in, delim_pos );
 
-    // http://, https://
-    if( ( *( str_in ) == 'h' && *( str_in + 1 ) == 't' && *( str_in + 2 ) == 't' && *( str_in + 3 ) == 'p' ) &&
-        ( ( *( str_in + 4 ) == ':' && *( str_in + 5 ) == '/' && *( str_in + 6 ) == '/' )
-          || ( *( str_in + 4 ) == 's' && *( str_in + 5 ) == ':' && *( str_in + 6 ) == '/' && *( str_in + 7 ) == '/' ) ) ){
-        linktype = LINKTYPE_HTTP;
-    }
-    // ftp://
-    else if( *( str_in ) == 'f' && *( str_in + 1 ) == 't' && *( str_in + 2 ) == 'p' && 
-             *( str_in + 3 ) == ':' && *( str_in + 4 ) == '/' && *( str_in + 5 ) == '/' ){
-        linktype = LINKTYPE_FTP;
-    }
-    // ttp://
-    else if( ( *( str_in ) == 't' && *( str_in + 1 ) == 't' && *( str_in + 2 ) == 'p'  ) && 
-             ( ( *( str_in + 3 ) == ':' && *( str_in + 4 ) == '/' && *( str_in + 5 ) == '/' )
-               || ( *( str_in + 3 ) == 's' && *( str_in + 4 ) == ':' && *( str_in + 5 ) == '/' && *( str_in + 6 ) == '/' ) ) ){
-        linktype = LINKTYPE_TTP;
-    }
-    // tp://
-    else if( ( *( str_in ) == 't' && *( str_in + 1 ) == 'p'  ) &&
-             ( ( *( str_in + 2 ) == ':' && *( str_in + 3 ) == '/' && *( str_in + 4 ) == '/' )
-               || ( *( str_in + 2 ) == 's' && *( str_in + 3 ) == ':' && *( str_in + 4 ) == '/' && *( str_in + 5 ) == '/' ) ) ){
-        linktype = LINKTYPE_TP;
-    }
-    
-    if( linktype == LINKTYPE_NONE ) return false;
+    if( linktype == MISC::SCHEME_NONE ) return false;
 
     // リンクの長さを取得
+    n_in = delim_pos;
     bool url_encode = false;
     char cchar = *( str_in + n_in );
-    n_in = 0;
     while(
-        // バッファサイズを越えない
+        // バッファサイズを超えない
         n_in < lng_in
-
-        // < ではない
-        && !( cchar == '&' && *( str_in + n_in +1 ) == 'l' && *( str_in + n_in +2 ) == 't'
-              && *( str_in + n_in +3) == ';' ) 
-
-        // > ではない
-        && !( cchar == '&' && *( str_in + n_in +1 ) == 'g' && *( str_in + n_in +2 ) == 't'
-              && *( str_in + n_in +3 ) == ';' ) 
-
-        // " ではない
-        && !( cchar == '&' && *( str_in + n_in +1 ) == 'q' && *( str_in + n_in +2 ) == 'u'
-              && *( str_in + n_in +3 ) == 'o' && *( str_in + n_in +4 ) == 't' && *( str_in + n_in +5 ) == ';' ) 
-
-        // [-a-zA-Z0-9!#$%&'()~=@;+:*,./?_] が続く限りwhileで回す
-        && (
-            ( cchar >= '0' && cchar <= '9' )
-            || ( cchar >= 'a' && cchar <= 'z' )
-            || ( cchar >= 'A' && cchar <= 'Z' )
-            || cchar == '!'
-            || cchar == '#'
-            || cchar == '$'
-            || cchar == '%'
-            || cchar == '&'
-            || cchar == '\''
-            || cchar == '('
-            || cchar == ')'
-            || cchar == '~'
-            || cchar == '-'
-            || cchar == '='
-            || cchar == '@'
-            || cchar == ';'
-            || cchar == '+'
-            || cchar == ':'
-            || cchar == '*'
-            || cchar == ','
-            || cchar == '.'
-            || cchar == '/'
-            || cchar == '?'
-            || cchar == '_'
-
-            || ( loose_url && cchar == '^' )
-
+        // URLとして扱う文字かどうか
+        && MISC::is_url_char( &cchar, loose_url )
+        // HTML特殊文字は除く( &〜; )
+        && ! (
+            *( str_in + n_in ) == '&'
+            && (
+                 (
+                   // quot;
+                   *( str_in + n_in + 1 ) == 'q'
+                   && *( str_in + n_in + 2 ) == 'u'
+                   && *( str_in + n_in + 3 ) == 'o'
+                   && *( str_in + n_in + 4 ) == 't'
+                   && *( str_in + n_in + 5 ) == ';'
+                 ) || (
+                   // lt;
+                   *( str_in + n_in + 1 ) == 'l'
+                   && *( str_in + n_in + 2 ) == 't'
+                   && *( str_in + n_in + 3 ) == ';'
+                 ) || (
+                   // gt;
+                   *( str_in + n_in + 1 ) == 'g'
+                   && *( str_in + n_in + 2 ) == 't'
+                   && *( str_in + n_in + 3 ) == ';'
+                 )
             )
-        ){
-
-        if( loose_url && cchar == '^' ) url_encode = true;
+        )
+    ){
+        // "^"と"|"はエンコードする
+        // "[]"はダウンローダに渡す用途のためにエンコードしないでおく
+        if( loose_url && ( cchar == '^' || cchar == '|' ) ) url_encode = true;
 
         ++n_in;
         cchar = *( str_in + n_in );
     }
 
-    // 最後に ()が来たら除く
+    // 最後に ()[] が来たら除く
     if( *( str_in + n_in -1 ) == '('
-        || *( str_in + n_in -1 ) == ')' ) --n_in;
+        || *( str_in + n_in -1 ) == ')'
+        || *( str_in + n_in -1 ) == '['
+        || *( str_in + n_in -1 ) == ']' ) --n_in;
+
+    // URLとして短かすぎる場合は除外する( 最短ドメイン名の例 "1.cc" )
+    if( n_in - delim_pos < 4 ) return false;
 
     int offset = 0;
-    if( linktype == LINKTYPE_TTP || linktype == LINKTYPE_TP ){ // ttp://, tp:// の場合、リンクの先頭にhを補完
+    if( linktype == MISC::SCHEME_TTP || linktype == MISC::SCHEME_TP ){ // ttp://, tp:// の場合、リンクの先頭にhを補完
 
         str_link[ 0 ] = 'h';
         offset = 1;
 
-        if( linktype == LINKTYPE_TP ){ // tp:// の場合、さらにリンク先頭にtを補完
+        if( linktype == MISC::SCHEME_TP ){ // tp:// の場合、さらにリンク先頭にtを補完
             str_link[ 1 ] = 't';
             offset = 2;
         }
@@ -1924,6 +1995,11 @@ bool NodeTreeBase::check_link( const char* str_in, int lng_in, int& n_in, char*
                 *( pos++ ) = '5';
                 *pos = 'e';
             }
+            else if( str_in[ i ] == '|' ){ // '|' -> %7c
+                *( pos++ ) = '%';
+                *( pos++ ) = '7';
+                *pos = 'c';
+            }
             else *pos = str_in[ i ];
         }
         *pos = '\0';
@@ -2410,10 +2486,16 @@ void NodeTreeBase::check_reference( int number )
 
                                 // 参照数を更新して色を変更
                                 ++( tmphead->headinfo->num_reference );
-                                if( tmphead->headinfo->num_reference >= 3 )
+
+                                // 参照回数大
+                                if( tmphead->headinfo->num_reference >= m_num_reference[ LINK_HIGH ] )
                                     tmphead->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK_HIGH;
-                                else if( tmphead->headinfo->num_reference >= 1 )
+
+                                // 参照回数中
+                                else if( tmphead->headinfo->num_reference >= m_num_reference[ LINK_LOW ] )
                                     tmphead->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK_LOW;
+
+                                // 参照無し
                                 else tmphead->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK;
                             }
                         }
@@ -2449,6 +2531,8 @@ void NodeTreeBase::clear_id_name()
 //
 void NodeTreeBase::update_id_name( int from_number, int to_number )
 {
+    if( ! CONFIG::get_check_id() ) return;
+
     if( empty() ) return;
     if( to_number < from_number ) return;
     for( int i = from_number ; i <= to_number; ++i ) check_id_name( i );
@@ -2502,8 +2586,8 @@ void NodeTreeBase::set_num_id_name( NODE* header, int num_id_name )
     if( header->headinfo->block[ BLOCK_ID_NAME ] ){
 
         header->headinfo->num_id_name = num_id_name;        
-        if( num_id_name >= 4 ) header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR_LINK_HIGH;
-        else if( num_id_name >= 2 ) header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR_LINK;
+        if( num_id_name >= m_num_id[ LINK_HIGH ] ) header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR_LINK_HIGH;
+        else if( num_id_name >= m_num_id[ LINK_LOW ] ) header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR_LINK;
         else header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR;
     }
 }
@@ -2516,7 +2600,7 @@ void NodeTreeBase::set_num_id_name( NODE* header, int num_id_name )
 //
 // 取り除いたらtrueを返す
 //
-// Thanks to 「ハッチ投稿」スレの24氏
+// Thanks to 「パッチ投稿」スレの24氏
 //
 // http://jd4linux.sourceforge.jp/cgi-bin/bbs/test/read.cgi/support/1151836078/24
 //
@@ -2524,26 +2608,32 @@ bool NodeTreeBase::remove_imenu( char* str_link )
 {
     const int lng_http = 7; // = strlen( "http://" );
 
-    if( ( str_link[ lng_http ] == 'i' && str_link[ lng_http +1 ] == 'm' )
-        || ( str_link[ lng_http ] == 'n' && str_link[ lng_http +1 ] == 'u' )
-        || ( str_link[ lng_http ] == 'p' && str_link[ lng_http +1 ] == 'i' ) ){
+    if(
+      ! (
+        ( str_link[ lng_http ] == 'i' && str_link[ lng_http + 1 ] == 'm' )
+        || ( str_link[ lng_http ] == 'n' && str_link[ lng_http + 1 ] == 'u' )
+        || ( str_link[ lng_http ] == 'p' && str_link[ lng_http + 1 ] == 'i' )
+      )
+    ) return false;
 
-        if( strstr( str_link, "http://ime.nu/" ) == str_link
-               || strstr( str_link, "http://ime.st/" ) == str_link
-               || strstr( str_link, "http://nun.nu/" ) == str_link
-               || strstr( str_link, "http://pinktower.com/" ) == str_link ){
+    if( memcmp( str_link, "http://ime.nu/", 14 ) == 0
+        || memcmp( str_link, "http://ime.st/", 14 ) == 0
+        || memcmp( str_link, "http://nun.nu/", 14 ) == 0
+        || memcmp( str_link, "http://pinktower.com/", 21 ) == 0 )
+    {
+		int linklen = strlen( str_link );
+		int cutsize = 0; 
 
-            int linklen = strlen( str_link ) +1;
-            int cutsize = 0; 
+		if( str_link[ lng_http ] == 'p' ) cutsize = 14; // = strlen( "pinktower.com/" )
+		else cutsize =  7; // = strlen( "ime.nu/" )
 
-            if( str_link[ lng_http ] == 'p' ) cutsize = 14; // = strlen( "pinktower.com/" )
-            else cutsize =  7; // = strlen( "ime.nu/" )
+        // "http://ime.nu/"等、URLがそれだけだった場合は削除しない
+        if( linklen == lng_http + cutsize ) return false;
 
-            memmove( str_link + lng_http, str_link + lng_http + cutsize, linklen - ( lng_http + cutsize ) );
+		memmove( str_link + lng_http, str_link + lng_http + cutsize, linklen + 1 - ( lng_http + cutsize ) );
 
-            return true;
-        }
-    }
+		return true;
+	}
 
     return false;
 }
