@@ -20,6 +20,13 @@ namespace JDLIB
 
 namespace DBTREE
 {
+    enum
+    {
+        LINK_LOW = 0,
+        LINK_HIGH,
+        LINK_NUM
+    };
+
     //ノードツリーのベースクラス
     class NodeTreeBase : public SKELETON::Loadable
     {
@@ -48,6 +55,12 @@ namespace DBTREE
         
         std::string m_subject;
 
+        // 参照で色を変える回数
+        int m_num_reference[ LINK_NUM ];
+
+        // 発言数で色を変える回数
+        int m_num_id[ LINK_NUM ];
+
         // あぼーん情報
         // 実体は親のarticlebaseクラスが持っていてcopy_abone_info()でコピーする
         std::list< std::string > m_list_abone_id;   // あぼーんするID
@@ -70,6 +83,7 @@ namespace DBTREE
         char* m_buffer_lines;
         int m_byte_buffer_lines_left;
         char* m_parsed_text;
+        bool m_check_update; // HEADによる更新チェックのみ
         
         // キャッシュ保存用ファイルハンドラ
         FILE *m_fout;
@@ -107,6 +121,7 @@ namespace DBTREE
         const size_t get_lng_dat() const { return m_lng_dat; }
         const bool is_broken() const{ return m_broken; }
         const std::string& get_ext_err() const { return m_ext_err; }
+        const bool is_checking_update() const { return m_check_update; }
 
         // number番のレスのヘッダノードのポインタを返す
         NODE* res_header( int number );
@@ -171,7 +186,7 @@ namespace DBTREE
         NODE* append_dat( const std::string& dat );
 
         // ロード開始
-        void download_dat();
+        void download_dat( const bool check_update );
 
         // あぼーんしているか
         bool get_abone( int number );
@@ -192,7 +207,7 @@ namespace DBTREE
         virtual void clear();
         virtual void init_loading();
 
-        // ロード用デー多作制
+        // ロード用データ作成
         virtual void create_loaderdata( JDLIB::LOADERDATA& data ){}
 
         // 保存前にrawデータを加工
