@@ -6,13 +6,14 @@
 #include "imageareaicon.h"
 
 #include "dbimg/img.h"
+#include "dbimg/imginterface.h"
 
 #include "jdlib/miscmsg.h"
 #include "jdlib/miscgtk.h"
+#include "jdlib/miscthread.h"
 
 #include "config/globalconf.h"
 
-#include "cache.h"
 #include "global.h"
 #include "httpcode.h"
 #include "colorid.h"
@@ -25,30 +26,22 @@
 // スレッドが起動する前に ImageAreaIcon が delete されると落ちるのでリストを使う
 
 Glib::StaticMutex icon_launcher_mutex = GLIBMM_STATIC_MUTEX_INIT;
-std::list< IMAGE::ImageAreaIcon* > icon_launcher_list_icon;
 
-void icon_launcher_set( IMAGE::ImageAreaIcon* icon ){
-    Glib::Mutex::Lock lock( icon_launcher_mutex);
-    icon_launcher_list_icon.push_back( icon );
-}
-
-void icon_launcher_remove( IMAGE::ImageAreaIcon* icon ){
-    Glib::Mutex::Lock lock( icon_launcher_mutex);
-    icon_launcher_list_icon.remove( icon );
-}
-
-void* icon_launcher( void* )
+void* icon_launcher( void* dat )
 {
+    Glib::Mutex::Lock lock( icon_launcher_mutex);
+
 #ifdef _DEBUG
     std::cout << "start icon_launcher\n";
 #endif
 
-    if( ! icon_launcher_list_icon.size() ) return 0;
-
-    IMAGE::ImageAreaIcon* icon = *( icon_launcher_list_icon.begin() );
-    icon_launcher_list_icon.remove( icon );
+    IMAGE::ImageAreaIcon* icon = ( IMAGE::ImageAreaIcon* )( dat );
     icon->show_image_thread();
 
+#ifdef _DEBUG
+    std::cout << "end\n";
+#endif
+
     return 0;
 }
 
@@ -84,11 +77,21 @@ ImageAreaIcon::~ImageAreaIcon()
     // デストラクタの中からdispatchを呼ぶと落ちるので dispatch不可にする
     set_dispatchable( false );
 
-    icon_launcher_remove( this );
+    stop();
     wait();
 }
 
 
+void ImageAreaIcon::stop()
+{
+#ifdef _DEBUG    
+    std::cout << "ImageAreaIcon::stop\n";
+#endif 
+
+    m_stop = true;
+}
+
+
 void ImageAreaIcon::wait()
 {
 #ifdef _DEBUG    
@@ -112,7 +115,7 @@ void ImageAreaIcon::show_image()
     std::cout << "ImageAreaIcon::show_image url = " << get_url() << std::endl;
 #endif 
 
-    wait();
+    if( m_thread )  return;
 
     // 既に画像が表示されている
     if( m_shown && get_img()->is_cached() ) return;
@@ -136,11 +139,20 @@ void ImageAreaIcon::show_image()
     // スレッドを起動してバックグラウンドでアイコン表示
     else{
 
-        icon_launcher_set( this );
+        // 縮小比率を計算
+        double scale;
+        int w_org = get_img()->get_width();
+        int h_org = get_img()->get_height();
+        double scale_w = ( double ) ICON_SIZE / w_org;
+        double scale_h = ( double ) ICON_SIZE / h_org;
+        scale = MIN( scale_w, scale_h );
+        set_width( (int)( w_org * scale ) );
+        set_height( (int)( h_org * scale ) );
+
         int status;
-        if( ( status = pthread_create( &m_thread, NULL, icon_launcher, NULL ) ) ){
-            MISC::ERRMSG( "ImageAreaIcon::show_image : could not start thread" );
-            icon_launcher_remove( this );
+        m_stop = false;
+        if( ( status = MISC::thread_create( &m_thread, icon_launcher, ( void* ) this ) ) ){
+            MISC::ERRMSG( std::string( "ImageAreaIcon::show_image : could not start thread " ) + strerror( status ) );
         }
     }
 }
@@ -155,29 +167,19 @@ void ImageAreaIcon::show_image_thread()
     std::cout << "ImageAreaIcon::show_image_thread url = " << get_url() << std::endl;
 #endif
 
-    try{
-        // 画像ロード
-        std::string path_cache = CACHE::path_img( get_url() );
-        Glib::RefPtr< Gdk::Pixbuf > pixbuf;
-        pixbuf = Gdk::Pixbuf::create_from_file( path_cache );
-        set_width_org( pixbuf->get_width() );
-        set_height_org( pixbuf->get_height() );
-
-        // 縮小比率を計算して縮小
-        double scale;
-        double scale_w = ( double ) ICON_SIZE / get_width_org();
-        double scale_h = ( double ) ICON_SIZE / get_height_org();
-        scale = MIN( scale_w, scale_h );
-        set_width( (int)( get_width_org() * scale ) );
-        set_height( (int)( get_height_org() * scale ) );
-        m_pixbuf_icon = pixbuf->scale_simple( get_width(), get_height(), Gdk::INTERP_NEAREST );
+    std::string errmsg;
+    bool pixbufonly = true;
+    if( get_img()->get_type() == DBIMG::T_BMP ) pixbufonly = false; // BMP の場合 pixbufonly = true にすると真っ黒になる
+    Glib::RefPtr< Gdk::PixbufLoader > loader = MISC::get_ImageLoder( get_img()->get_cache_path(), m_stop, pixbufonly, errmsg );
+    if( loader && loader->get_pixbuf() ) m_pixbuf_icon = loader->get_pixbuf()->scale_simple( get_width(), get_height(), Gdk::INTERP_NEAREST );;
 
+    if( m_pixbuf_icon ){
         m_imagetype = IMAGE_SHOW_ICON;
         m_shown = true;
     }
-    catch( Glib::Error& err )
-    {
-        set_errmsg( err.what() );
+    else{
+
+        set_errmsg( errmsg );
         MISC::ERRMSG( get_errmsg() );
 
         show_indicator( false );
@@ -194,6 +196,19 @@ void ImageAreaIcon::show_image_thread()
 }
 
 
+//
+// インジケータ幅、高さ
+const int ImageAreaIcon::width_indicator()
+{
+    return MAX( 1, get_width()/4 );
+}
+
+const int ImageAreaIcon::height_indicator()
+{
+    return MAX( 1, get_height()/4 );
+}
+
+
 //
 // インジゲータ画像表示
 // 
@@ -206,8 +221,8 @@ void ImageAreaIcon::show_indicator( bool loading )
     if( ! m_pixbuf ){
 
         m_pixbuf = Gdk::Pixbuf::create( Gdk::COLORSPACE_RGB, false, 8, get_width(), get_height() );
-        m_pixbuf_err = Gdk::Pixbuf::create( Gdk::COLORSPACE_RGB, false, 8, get_width()/4, get_height()/4 );
-        m_pixbuf_loading = Gdk::Pixbuf::create( Gdk::COLORSPACE_RGB, false, 8, get_width()/4, get_height()/4 );
+        m_pixbuf_err = Gdk::Pixbuf::create( Gdk::COLORSPACE_RGB, false, 8, width_indicator(), height_indicator() );
+        m_pixbuf_loading = Gdk::Pixbuf::create( Gdk::COLORSPACE_RGB, false, 8, width_indicator(), height_indicator() );
 
         assert( m_pixbuf );
         assert( m_pixbuf_err );
@@ -219,10 +234,10 @@ void ImageAreaIcon::show_indicator( bool loading )
     }
 
     // 読み込み中
-    if( loading ) m_pixbuf_loading->copy_area( 0, 0, get_width()/4, get_height()/4, m_pixbuf, 4, 4 );
+    if( loading ) m_pixbuf_loading->copy_area( 0, 0, width_indicator(), height_indicator(), m_pixbuf, 4, 4 );
 
     // エラー
-    else  m_pixbuf_err->copy_area( 0, 0, get_width()/4, get_height()/4, m_pixbuf, 4, 4 );
+    else  m_pixbuf_err->copy_area( 0, 0, width_indicator(), height_indicator(), m_pixbuf, 4, 4 );
 
     m_imagetype = IMAGE_SHOW_INDICATOR;
 }
