@@ -47,6 +47,9 @@ ImageViewMain::ImageViewMain( const std::string& url )
     std::cout << "ImageViewMain::ImageViewMain : " << get_url() << std::endl;
 #endif
 
+    // コントロールモード設定
+    get_control().add_mode( CONTROL::MODE_IMAGEVIEW );
+
     // スクロールウィンドウを作ってEventBoxを貼る
     m_scrwin = Gtk::manage( new Gtk::ScrolledWindow() );
     assert( m_scrwin );
@@ -155,7 +158,7 @@ void ImageViewMain::show_instruct_diag()
     IMAGE::get_admin()->set_command_immediately( "disable_fold_win" );
 
     SKELETON::MsgDiag mdiag( NULL, 
-        "画像ビューからスレ一ビューに戻る方法として\n\n(1) マウスジェスチャを使う( 右ボタンを押しながら左にドラッグして離す )\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレビューアイコンを押す\n\n(5) 表示メニューからスレビューを選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。" );
+        "画像ビューからスレビューに戻る方法として\n\n(1) マウスジェスチャを使う( マウスの右ボタンを押しながら左または下にドラッグして右ボタンを離す )\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレビューアイコンを押す\n\n(5) 表示メニューからスレビューを選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。" );
     Gtk::CheckButton chkbutton( "今後表示しない" );
     mdiag.get_vbox()->pack_start( chkbutton, Gtk::PACK_SHRINK );
     mdiag.set_title( "ヒント" );
@@ -362,7 +365,7 @@ bool ImageViewMain::slot_motion_notify( GdkEventMotion* event )
     if( m_scrwin ){
 
         GdkEventButton event_button;
-        get_control().get_eventbutton( CONTROL::ClickButton, event_button );
+        get_control().get_eventbutton( CONTROL::ScrollImageButton, event_button );
 
 #ifdef _DEBUG
         std::cout << "state = " << event->state << " / " << GDK_BUTTON1_MASK << " button = " << event_button.button << std::endl;
