@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 //#define _DEBUG
 //#define _DEBUG_CHUNKED
@@ -7,6 +7,7 @@
 #include "loader.h"
 #include "miscmsg.h"
 #include "miscutil.h"
+#include "miscthread.h"
 
 #include "skeleton/loadable.h"
 
@@ -35,9 +36,6 @@
 #define TIMEOUT_MIN 10             
 
 
-typedef void* ( *FUNC )( void * );
-
-
 //
 // トークン処理
 //
@@ -307,6 +305,7 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     m_data.timeout = MAX( TIMEOUT_MIN, data_in.timeout );
     m_data.ex_field = data_in.ex_field;
     m_data.basicauth = data_in.basicauth;
+    m_data.use_ipv6 = data_in.use_ipv6;
 
 #ifdef _DEBUG    
     std::cout << "host: " << m_data.host << std::endl;
@@ -328,12 +327,12 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
 #endif
 
     // スレッドを起動して run_main() 実行
-    m_stop = false;
     int status;
-    if( ( status = pthread_create( &m_thread, NULL,  ( FUNC ) launcher, ( void * ) this ) )){
+    m_stop = false;
+    if( ( status = MISC::thread_create( &m_thread, ( STARTFUNC ) launcher, ( void * ) this ) )){
 
         m_data.code = HTTP_ERR;
-        m_data.str_code = std::string( "pthread_create failed : " ) + strerror( status );
+        m_data.str_code = std::string( "Loader::run : could not start thread : " ) + strerror( status );
         MISC::ERRMSG( m_data.str_code );
         return false;
     }
@@ -608,7 +607,17 @@ void Loader::run_main()
         if( m_stop ) break;
 
         // サーバ側がcloseした
-        if( read_size == 0 ) break;
+        if( read_size == 0 ){
+
+            // ヘッダを取得する前にcloseした
+            if( receiving_header && m_data.size_data == 0 ){
+                m_data.code = HTTP_ERR;         
+                errmsg = "no data";
+                goto EXIT_LOADING;
+            }
+
+            break;
+        }
 
         // ヘッダ取得
         if( receiving_header ){
@@ -737,7 +746,8 @@ struct addrinfo* Loader::get_addrinfo( const std::string& hostname, int port )
     const int poststrlng = 256;
     char port_str[ poststrlng ];
     memset( &hints, 0, sizeof( addrinfo ) );
-    hints.ai_family = AF_UNSPEC;
+    if( m_data.use_ipv6 ) hints.ai_family = AF_UNSPEC;
+    else hints.ai_family = AF_INET;
     hints.ai_socktype = SOCK_STREAM;
 
     snprintf( port_str, poststrlng, "%d", port );
@@ -749,6 +759,7 @@ struct addrinfo* Loader::get_addrinfo( const std::string& hostname, int port )
     
 #ifdef _DEBUG    
     std::cout << "host = " << hostname
+              << " ipv6 = " << m_data.use_ipv6
               << ", ip =" << inet_ntoa( (  ( sockaddr_in* )( res->ai_addr ) )->sin_addr ) << std::endl;
 #endif
 
@@ -875,8 +886,6 @@ bool Loader::receive_header( char* buf, size_t& read_size )
 bool Loader::analyze_header()
 {
     // コード
-    m_data.code = HTTP_INIT;
-    m_data.str_code.clear();
     std::string str_tmp = analyze_header_option( "HTTP/1.1 " );
     if( ! str_tmp.empty() ){
         m_data.str_code = "HTTP/1.1 "  + str_tmp;
@@ -885,12 +894,20 @@ bool Loader::analyze_header()
         str_tmp = analyze_header_option( "HTTP/1.0 " );
         if( ! str_tmp.empty() ) m_data.str_code = "HTTP/1.0 "  + str_tmp;
     }
-    size_t i = str_tmp.find( " " );
-    if( i == std::string::npos ){
+
+    if( str_tmp.empty() ){
         MISC::ERRMSG( "could not find HTTP/1.1" );
         return false;
     }
-    m_data.code = atoi( str_tmp.substr( 0, i ).c_str() );
+
+    size_t i = str_tmp.find( " " );
+    if( i == std::string::npos ) m_data.code = atoi( str_tmp.c_str() );
+    else m_data.code = atoi( str_tmp.substr( 0, i ).c_str() );
+
+    if( m_data.code == 0 ){
+        MISC::ERRMSG( "could not get http status code" );
+        return false;
+    }
 
     // サイズ
     m_data.length = 0;
@@ -956,14 +973,15 @@ bool Loader::analyze_header()
 //
 // analyze_header() から呼ばれるオプションの値を取り出す関数
 //
-std::string Loader::analyze_header_option( char* option )
+std::string Loader::analyze_header_option( const std::string& option )
 {
     size_t i = 0, i2 = 0;
     i = m_data.str_header.find( option, 0 );    
     if( i != std::string::npos ){
+        const size_t option_length = option.length();
         i2 = m_data.str_header.find( "\r\n", i );
         if( i2 == std::string::npos ) i2 = m_data.str_header.find( "\n", i );
-        if( i2 != std::string::npos ) return m_data.str_header.substr( i + strlen( option ), i2 - ( i + strlen( option ) ) );
+        if( i2 != std::string::npos ) return m_data.str_header.substr( i + option_length, i2 - ( i + option_length ) );
     }
 
     return std::string();
@@ -974,11 +992,12 @@ std::string Loader::analyze_header_option( char* option )
 //
 // analyze_header() から呼ばれるオプションの値を取り出す関数(リスト版)
 //
-std::list< std::string > Loader::analyze_header_option_list( char* option )
+std::list< std::string > Loader::analyze_header_option_list( const std::string& option )
 {
     std::list< std::string > str_list;
     
     size_t i = 0, i2 = 0;
+    const size_t option_length = option.length();
 
     for(;;){
 
@@ -989,7 +1008,7 @@ std::list< std::string > Loader::analyze_header_option_list( char* option )
         if( i2 == std::string::npos ) i2 = m_data.str_header.find( "\n", i );
         if( i2 == std::string::npos ) break;
 
-        str_list.push_back( m_data.str_header.substr( i + strlen( option ), i2 - ( i + strlen( option ) ) ) );
+        str_list.push_back( m_data.str_header.substr( i + option_length, i2 - ( i + option_length ) ) );
     }
 
     return str_list;
