@@ -7,6 +7,9 @@
 #include "messageadmin.h"
 #include "messageviewbase.h"
 #include "post.h"
+#include "toolbar.h"
+
+#include "skeleton/msgdiag.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/misctime.h"
@@ -24,7 +27,11 @@
 #include "viewfactory.h"
 #include "controlutil.h"
 #include "controlid.h"
+#include "fontid.h"
 #include "cache.h"
+#include "session.h"
+#include "colorid.h"
+#include "global.h"
 
 #include <sstream>
 #include <sys/time.h>
@@ -34,6 +41,8 @@ using namespace MESSAGE;
 
 #define MAX_STR_ICONV 128*1024
 
+#define PASS_TIMEOUT 500
+#define PASS_MAXTIME 120
 
 enum{
     PAGE_MESSAGE = 0,
@@ -45,17 +54,16 @@ MessageViewBase::MessageViewBase( const std::string& url )
     : SKELETON::View( url ),
       m_post( 0 ),
       m_preview( 0 ),
-      m_button_write( ICON::WRITE ),
-      m_button_cancel( Gtk::Stock::CLOSE ),
-      m_button_undo( Gtk::Stock::UNDO ),
-      m_entry_subject( false, " [ " + DBTREE::board_name( url ) + " ]  ", "" )
+      m_enable_menuslot( true ),
+      m_enable_focus( true ),
+      m_counter( 0 )
 {
 #ifdef _DEBUG
     std::cout << "MessageViewBase::MessageViewBase " << get_url() << std::endl;
 #endif
 
     // コントロールモード設定
-    get_control().set_mode( CONTROL::MODE_MESSAGE );
+    get_control().add_mode( CONTROL::MODE_MESSAGE );
 
     m_max_line = DBTREE::line_number( get_url() ) * 2;
     m_max_str = DBTREE::message_count( get_url() );
@@ -90,9 +98,51 @@ MessageViewBase::~MessageViewBase()
 }
 
 
+MessageToolBar* MessageViewBase::get_messagetoolbar()
+{
+    return dynamic_cast< MessageToolBar* >( get_toolbar() );
+}
+
+
+SKELETON::LabelEntry* MessageViewBase::get_entry_subject()
+{
+    if( ! get_messagetoolbar() ) return NULL;
+    return &get_messagetoolbar()->m_entry_subject;
+}
+
+
+//
+// コピー用URL( readcgi型 )
+//
+// メインウィンドウのURLバーなどに表示する)
+//
+const std::string MessageViewBase::url_for_copy()
+{
+    return DBTREE::url_readcgi( get_url(), 0, 0 );
+}
+
+
+
 void MessageViewBase::clock_in()
 {
     if( m_preview ) m_preview->clock_in();
+
+    // 経過時刻表示
+    ++m_counter;
+    if( m_counter % ( PASS_TIMEOUT / TIMER_TIMEOUT ) == 0 ){
+
+        m_counter = 0;
+
+        time_t left = DBTREE::board_write_leftsec( get_url() );
+        if( left ){
+            m_str_pass = "  ( 書込規制中 残り " + MISC::itostr( left ) + " 秒 )";
+            MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() + m_str_pass );
+        }
+        else if( ! m_str_pass.empty() ){
+            m_str_pass = std::string();
+            MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
+        }
+    }
 }
 
 
@@ -120,6 +170,19 @@ void MessageViewBase::init_font( const std::string& fontname )
 }
 
 
+//
+// 色初期化
+//
+void MessageViewBase::init_color()
+{
+    m_text_message.modify_text( Gtk::STATE_NORMAL, Gdk::Color( CONFIG::get_color( COLOR_CHAR_MESSAGE ) ) );
+    m_text_message.modify_text( Gtk::STATE_SELECTED, Gdk::Color( CONFIG::get_color( COLOR_CHAR_MESSAGE_SELECTION ) ) );
+    m_text_message.modify_base( Gtk::STATE_NORMAL, Gdk::Color( CONFIG::get_color( COLOR_BACK_MESSAGE ) ) );
+    m_text_message.modify_base( Gtk::STATE_SELECTED, Gdk::Color( CONFIG::get_color( COLOR_BACK_MESSAGE_SELECTION ) ) );
+}
+
+
+
 //
 // コマンド
 //
@@ -127,11 +190,74 @@ bool MessageViewBase::set_command( const std::string& command, const std::string
 {
     if( command == "empty" ) return get_message().empty();
 
-    if( command == "loading" ){
+    else if( command == "loading" ){
         if( !m_post ) return false;
         return m_post->is_loading();
     }
 
+    else if( command == "exec_Write" ) slot_write_clicked();
+    else if( command == "tab_left" ) tab_left();
+    else if( command == "tab_right" ) tab_right();
+    else if( command == "focus_write" ) focus_writebutton();
+
+    // メッセージをクリア
+    else if( command == "clear_message" ){
+
+        m_text_message.set_text( std::string() );
+
+        if( m_notebook.get_current_page() != PAGE_MESSAGE ){
+            m_enable_focus = false;
+            m_notebook.set_current_page( PAGE_MESSAGE );
+            m_enable_focus = true;
+        }
+    }
+
+    // メッセージを追加
+    else if( command == "add_message" )
+    {
+        std::string caution;
+
+        // 追加する文字列が制限値を超えていないかチェック
+        if( m_max_str && int( arg.length() ) > m_max_str ) caution.append( "文字数" );
+        if( m_max_line && MISC::count_str( arg, "\n" ) > m_max_line )
+        {
+            if( ! caution.empty() ) caution.append( "及び" );
+            caution.append( "改行数" );
+        }
+
+        if( ! caution.empty() )
+        {
+            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                                     caution.append( "がスレッドの制限値を超えています。\n\n追加しますか？" ),
+                                     false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return false;
+        }
+
+        m_text_message.insert_str( arg, true );
+    }
+
+    // メッセージ保存
+    else if ( "save_message" )
+    {
+        if( ! get_message().empty() ){
+
+            std::string filename = "draft-" + MISC::get_filename( get_url() );
+            if( filename.find( ".dat" ) != std::string::npos ) filename = MISC::replace_str( filename, ".dat", ".txt" );
+            else filename += ".txt";
+            std::string save_to = CACHE::open_save_diag( MESSAGE::get_admin()->get_win(), SESSION::get_dir_draft(), filename, CACHE::FILE_TYPE_TEXT );
+            if( ! save_to.empty() ){
+
+                SESSION::set_dir_draft( MISC::get_dir( save_to ) );
+
+                if( CACHE::save_rawdata( save_to, get_message() ) != get_message().raw().length() ){
+                    SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                                             "保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
+                    mdiag.run();
+                }
+            }
+        }
+    }
+
     return false;
 }
 
@@ -165,20 +291,22 @@ void MessageViewBase::save_name()
 //
 void MessageViewBase::pack_widget()
 {
-    m_entry_subject.set_text( DBTREE::article_subject( get_url() ) );
+    // ツールバー
+    set_toolbar( Gtk::manage( new MessageToolBar( " [ " + DBTREE::board_name( get_url() ) + " ]  " ) ) );
+    get_messagetoolbar()->m_entry_subject.set_text( DBTREE::article_subject( get_url() ) );
+    get_messagetoolbar()->m_button_not_close.set_active( ! SESSION::get_close_mes() );
 
-    m_button_write.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_write_clicked ) );
-    m_button_cancel.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_cancel_clicked ) );
-    m_button_undo.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_undo_clicked ) );
+    get_messagetoolbar()->m_button_write.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_write_clicked ) );
+    get_messagetoolbar()->get_close_button().signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_close_clicked ) );
+    get_messagetoolbar()->m_button_open.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_draft_open ) );
+    get_messagetoolbar()->m_button_undo.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_undo_clicked ) );
+    get_messagetoolbar()->m_button_not_close.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_not_close_clicked ) );
+    get_messagetoolbar()->m_button_preview.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_preview_clicked ) );
     
-    m_tooltip.set_tip( m_button_write, CONTROL::get_label_motion( CONTROL::ExecWrite ) );
-    m_tooltip.set_tip( m_button_cancel, CONTROL::get_label_motion( CONTROL::CancelWrite ) );
-    m_tooltip.set_tip( m_button_undo, CONTROL::get_label_motion( CONTROL::UndoEdit ) );
+    get_messagetoolbar()->show_toolbar();
 
-    m_toolbar.pack_start( m_button_write, Gtk::PACK_SHRINK );
-    m_toolbar.pack_start( m_entry_subject, Gtk::PACK_EXPAND_WIDGET, 2 );
-    m_toolbar.pack_start( m_button_undo, Gtk::PACK_SHRINK );
-    m_toolbar.pack_end( m_button_cancel, Gtk::PACK_SHRINK );
+    if( SESSION::get_close_mes() ) get_messagetoolbar()->get_close_button().set_sensitive( true );
+    else get_messagetoolbar()->get_close_button().set_sensitive( false );
 
     // 書き込みビュー
     m_label_name.set_alignment( Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER );
@@ -189,6 +317,9 @@ void MessageViewBase::pack_widget()
     m_check_fixname.set_label( "固定" );
     m_check_fixmail.set_label( "固定" );
 
+    m_tooltip.set_tip( m_check_fixname, "チェックすると名前欄を保存して固定にする" );
+    m_tooltip.set_tip( m_check_fixmail, "チェックするとメール欄を保存して固定にする" );
+
     // 名前
     
     if( DBTREE::write_fixname( get_url() ) ){
@@ -205,7 +336,12 @@ void MessageViewBase::pack_widget()
         m_entry_mail.set_text( DBTREE::write_mail( get_url() ) );
     }
     else if( ! DBTREE::board_get_write_mail( get_url() ).empty() ){
-        m_entry_mail.set_text( DBTREE::board_get_write_mail( get_url() ) );
+
+        std::string tmpmail = DBTREE::board_get_write_mail( get_url() );
+
+        // 空白セット
+        if( tmpmail == JD_MAIL_BLANK ) m_entry_mail.set_text( std::string() );
+        else m_entry_mail.set_text( tmpmail );
     }
     else m_entry_mail.set_text( "sage" );
 
@@ -216,30 +352,31 @@ void MessageViewBase::pack_widget()
     m_hbox_name_mail.pack_start( m_check_fixmail, Gtk::PACK_SHRINK );
     m_hbox_name_mail.pack_start( m_entry_mail );
 
-#if GTKMMVER >= 260
-    m_statbar.pack_start( m_label_stat, Gtk::PACK_SHRINK );
-#endif
-
     m_msgview.pack_start( m_hbox_name_mail, Gtk::PACK_SHRINK );    
     m_msgview.pack_start( m_text_message );
 
     m_text_message.set_accepts_tab( false );
-    m_text_message.sig_key_release().connect( sigc::mem_fun(*this, &MessageViewBase::slot_key_release ) );    
+    m_text_message.sig_key_press().connect( sigc::mem_fun(*this, &MessageViewBase::slot_key_press ) );    
+    m_text_message.sig_button_press().connect( sigc::mem_fun(*this, &MessageViewBase::slot_button_press ) );
     m_text_message.get_buffer()->signal_changed().connect( sigc::mem_fun(*this, &MessageViewBase::show_status ) );
 
     // プレビュー
     m_preview = CORE::ViewFactory( CORE::VIEW_ARTICLEPREVIEW, get_url() );
 
+    m_notebook.set_show_tabs( false );
     m_notebook.append_page( m_msgview, "メッセージ" );
     m_notebook.append_page( *m_preview, "プレビュー" );
     m_notebook.signal_switch_page().connect( sigc::mem_fun( *this, &MessageViewBase::slot_switch_page ) );
+    m_notebook.set_current_page( PAGE_MESSAGE );
 
-    pack_start( m_toolbar, Gtk::PACK_SHRINK );
+    pack_start( *get_messagetoolbar(), Gtk::PACK_SHRINK );
     pack_start( m_notebook );
-    pack_start( m_statbar, Gtk::PACK_SHRINK );
 
     // フォントセット
-    init_font( CONFIG::get_fontname_message() );
+    init_font( CONFIG::get_fontname( FONT_MESSAGE ) );
+
+    // 色セット
+    init_color();
 
     show_status();
 }
@@ -258,9 +395,13 @@ void MessageViewBase::redraw_view()
 
 void MessageViewBase::focus_view()
 {
-    m_text_message.focus_view();
-}
+#ifdef _DEBUG
+    std::cout << "MessageViewBase::focus_view page = " << m_notebook.get_current_page() << std::endl;
+#endif
 
+    if( m_notebook.get_current_page() == PAGE_MESSAGE ) m_text_message.focus_view();
+    else if( m_preview && m_notebook.get_current_page() == PAGE_PREVIEW ) m_preview->focus_view();
+}
 
 
 //
@@ -274,20 +415,25 @@ void MessageViewBase::operate_view( const int& control )
             
             // 書き込まずに閉じる
         case CONTROL::CancelWrite:
-            slot_cancel_clicked();
+            close_view();
             break;
 
             // 書き込み実行
         case CONTROL::ExecWrite:
-            slot_write_clicked();
+            MESSAGE::get_admin()->set_command( "exec_Write" );
             break;
 
         case CONTROL::TabLeft:
-            tab_left();
+            MESSAGE::get_admin()->set_command( "tab_left" );
             break;
 
         case CONTROL::TabRight:
-            tab_right();
+            MESSAGE::get_admin()->set_command( "tab_right" );
+            break;
+
+            // 書き込みボタンにフォーカスを移す
+        case CONTROL::FocusWrite:
+            focus_writebutton();
             break;
     }
 }
@@ -299,14 +445,15 @@ void MessageViewBase::operate_view( const int& control )
 //
 void MessageViewBase::slot_write_clicked()
 {
-/* 書き込み確認(やってみたらうざかったので様子見)
-
-    Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( m_ui_manager->get_widget( "/popup_menu_write" ) );
-    if( popupmenu ) popupmenu->popup( 0, gtk_get_current_event_time() );      
-*/
+    time_t left = DBTREE::board_write_leftsec( get_url() );
+    if( left ){
+        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み規制中です ( 残り " + MISC::itostr( left ) + " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。" );
+        mdiag.run();
+        return;
+    }
 
     if( m_post && m_post->is_loading() ){
-        Gtk::MessageDialog mdiag( "書き込み中です" );
+        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み中です" );
         mdiag.run();
         return;
     }
@@ -319,7 +466,7 @@ void MessageViewBase::slot_write_clicked()
 
         std::string name = get_entry_name().get_text();
         if( name.empty() ){
-            Gtk::MessageDialog mdiag( "名前欄が空白です。fusianasan 書き込みになる可能性があります。" );
+            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "名前欄が空白です。fusianasan 書き込みになる可能性があります。" );
             mdiag.run();
             return;
         }
@@ -330,7 +477,7 @@ void MessageViewBase::slot_write_clicked()
     if( m_max_line ){
 
         if( m_text_message.get_buffer()->get_line_count() > m_max_line ){
-            Gtk::MessageDialog mdiag( "行数が多すぎます。" );
+            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "行数が多すぎます。" );
             mdiag.run();
             return;
         }
@@ -340,7 +487,7 @@ void MessageViewBase::slot_write_clicked()
     if( m_max_str ){
 
         if( m_lng_str_enc > m_max_str ){
-            Gtk::MessageDialog mdiag( "文字数が多すぎます。" );
+            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "文字数が多すぎます。" );
             mdiag.run();
             return;
         }
@@ -351,11 +498,33 @@ void MessageViewBase::slot_write_clicked()
 
 
 //
-// キャンセルボタンを押した
+// ファイル挿入
 //
-void MessageViewBase::slot_cancel_clicked()
+void MessageViewBase::slot_draft_open()
 {
-    close_view();
+    std::string open_path = CACHE::open_load_diag( MESSAGE::get_admin()->get_win(), SESSION::get_dir_draft(), CACHE::FILE_TYPE_TEXT );
+
+    if( ! open_path.empty() )
+    {
+        std::string draft;
+
+        SESSION::set_dir_draft( MISC::get_dir( open_path ) );
+        CACHE::load_rawdata( open_path, draft );
+        if( ! draft.empty() ) set_command( "add_message", draft );
+    }
+}
+
+
+//
+// closeボタンを押した
+//
+void MessageViewBase::slot_close_clicked()
+{
+    if( !SESSION::get_close_mes() ){
+        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "「ビューを閉じない」ボタンが押されています。" );
+        mdiag.run();
+    }
+    else close_view();
 }
 
 
@@ -369,9 +538,40 @@ void MessageViewBase::slot_undo_clicked()
 
 
 //
-// テキストビューのキー操作
+// ビューを閉じないボタンを押した
 //
-bool MessageViewBase::slot_key_release( GdkEventKey* event )
+void MessageViewBase::slot_not_close_clicked()
+{
+    if( ! m_enable_menuslot ) return;
+    if( ! get_messagetoolbar() ) return;
+
+    SESSION::set_close_mes( ! SESSION::get_close_mes() );
+
+    if( SESSION::get_close_mes() ) get_messagetoolbar()->get_close_button().set_sensitive( true );
+    else get_messagetoolbar()->get_close_button().set_sensitive( false );
+}
+
+
+//
+// プレビューボタンを押した
+//
+void MessageViewBase::slot_preview_clicked()
+{
+    if( ! m_enable_menuslot ) return;
+
+#ifdef _DEBUG
+    std::cout << "MessageViewBase::slot_preview_clicked page = " << m_notebook.get_current_page() << std::endl;
+#endif
+
+    if( m_notebook.get_current_page() == PAGE_MESSAGE ) tab_right();
+    else tab_left();
+}
+
+
+//
+// テキストビューでキーを押した
+//
+bool MessageViewBase::slot_key_press( GdkEventKey* event )
 {
 #ifdef _DEBUG_KEY
     guint key = event->keyval;
@@ -379,7 +579,7 @@ bool MessageViewBase::slot_key_release( GdkEventKey* event )
     bool shift = ( event->state ) & GDK_SHIFT_MASK;
     bool alt = ( event->state ) & GDK_MOD1_MASK;
 
-    std::cout << "MessageViewBase::slot_key_release"
+    std::cout << "MessageViewBase::slot_key_press"
               << " key = " << key
               << " ctrl = " << ctrl
               << " shift = " << shift
@@ -392,17 +592,32 @@ bool MessageViewBase::slot_key_release( GdkEventKey* event )
 }
 
 
+//
+// テキストビューでマウスボタン押した
+//
+bool MessageViewBase::slot_button_press( GdkEventButton* event )
+{
+#ifdef _DEBUG
+    std::cout << "MessageViewBase::slot_button_press\n";
+#endif
+
+    MESSAGE::get_admin()->set_command( "switch_admin" );
+
+    return true;
+}
+
+
 
 //
 // フォントの更新
 //
 void MessageViewBase::relayout()
 {
-    init_font( CONFIG::get_fontname_message() );
+    init_font( CONFIG::get_fontname( FONT_MESSAGE ) );
+    init_color();
 }
 
 
-
 //
 // 閉じる
 //
@@ -422,10 +637,14 @@ void MessageViewBase::close_view()
 //
 void MessageViewBase::tab_left()
 {
+#ifdef _DEBUG
+    std::cout << "MessageViewBase::tab_left\n";
+#endif
+
     int page = m_notebook.get_current_page();
-    if( page == PAGE_MESSAGE ) return;
+    if( page == PAGE_MESSAGE ) m_notebook.set_current_page( PAGE_PREVIEW );
+    else m_notebook.set_current_page( PAGE_MESSAGE );
 
-    m_notebook.set_current_page( PAGE_MESSAGE );
     focus_view();
 }
 
@@ -435,15 +654,29 @@ void MessageViewBase::tab_left()
 //
 void MessageViewBase::tab_right()
 {
+#ifdef _DEBUG
+    std::cout << "MessageViewBase::tab_right\n";
+#endif
+
     int page = m_notebook.get_current_page();
-    if( page == PAGE_PREVIEW ) return;
+    if( page == PAGE_PREVIEW ) m_notebook.set_current_page( PAGE_MESSAGE );
+    else m_notebook.set_current_page( PAGE_PREVIEW );
 
-    m_notebook.set_current_page( PAGE_PREVIEW );
     m_preview->focus_view();
 }
 
 
 
+//
+// 書き込みボタンをフォーカス
+//
+void MessageViewBase::focus_writebutton()
+{
+    if( ! get_messagetoolbar() ) return;
+    get_messagetoolbar()->m_button_write.grab_focus();
+}
+
+
 //
 // 書き込み
 //
@@ -477,21 +710,25 @@ void MessageViewBase::post_fin()
         ){
         save_postlog();
         m_text_message.set_text( std::string() );
+
         close_view();
+
         reload();
     }
 
     // タイムアウト
     else if( code == HTTP_TIMEOUT ){
 
-        Gtk::MessageDialog mdiag( "タイムアウトしました\n\n書き込み自体は成功している可能性があります。\nメッセージのバックアップをとってからスレを再読み込みして下さい。" );
+        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                                 "タイムアウトしました\n\n書き込み自体は成功している可能性があります。\nメッセージのバックアップをとってからスレを再読み込みして下さい。" );
         mdiag.run();
     }
 
     // 失敗
     else if( code != HTTP_CANCEL ){
 
-        Gtk::MessageDialog mdiag( "書き込みに失敗しました\n\n" + m_post->errmsg(), false, Gtk::MESSAGE_ERROR  );
+        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                                 "書き込みに失敗しました\n\n" + m_post->errmsg(), false, Gtk::MESSAGE_ERROR  );
         mdiag.run();
     }
 }
@@ -506,15 +743,19 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
     std::cout << "MessageViewBase::slot_switch_page : " << get_url() << " page = " << page << std::endl;
 #endif
 
+    // toggle　アクションを activeにするとスロット関数が呼ばれるので処理しないようにする
+    m_enable_menuslot = false;
+
     // プレビュー表示
-    if( m_preview && page == PAGE_PREVIEW ){
+    if( get_messagetoolbar() && m_preview && page == PAGE_PREVIEW ){
 
-        // 編集ボタン無効化
-        m_button_undo.set_sensitive( false );
+        // 各ボタンの状態更新
+        get_messagetoolbar()->m_button_undo.set_sensitive( false );
+        get_messagetoolbar()->m_button_open.set_sensitive( false );
+        get_messagetoolbar()->m_button_preview.set_active( true );
 
-        std::string msg = m_text_message.get_text();
-        msg = MISC::replace_str( msg, "<", "&lt;" );
-        msg = MISC::replace_str( msg, ">", "&gt;" );
+        // URLを除外してエスケープ
+        std::string msg = MISC::html_escape( m_text_message.get_text(), false );
         msg = MISC::replace_str( msg, "\n", " <br> " );
         
         std::stringstream ss;
@@ -522,13 +763,11 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
         // 名前 + トリップ
         if( ! m_entry_name.get_text().empty() ){
 
-            std::string name = m_entry_name.get_text();
-            name = MISC::replace_str( name, "<", "&lt;" );
-            name = MISC::replace_str( name, ">", "&gt;" );
+            std::string name = MISC::html_escape( m_entry_name.get_text() );
 
             std::string trip;
 
-            unsigned int i = name.find( "#" );
+	    std::string::size_type i = name.find( "#" );
             if( i != std::string::npos ){
 
                 trip = MISC::get_trip( name.substr( i+1 ), DBTREE::board_charset( get_url() ) );
@@ -540,9 +779,7 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
         }
         else ss << DBTREE::default_noname( get_url() );
 
-        std::string mail = m_entry_mail.get_text();
-        mail = MISC::replace_str( mail, "<", "&lt;" );
-        mail = MISC::replace_str( mail, ">", "&gt;" );
+        std::string mail = MISC::html_escape( m_entry_mail.get_text() );
 
         ss << "<>" << mail  << "<>";
 
@@ -557,17 +794,25 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
         std::cout << ss.str() << std::endl;
 #endif
 
+        m_preview->set_command( "clear_screen" );
         m_preview->set_command( "append_dat", ss.str() );
     }
 
     // メッセージビュー
-    else if( page == PAGE_MESSAGE ){
+    else if( get_messagetoolbar() && page == PAGE_MESSAGE ){
 
-        // 編集ボタン有効化
-        m_button_undo.set_sensitive( true );
-
-        MESSAGE::get_admin()->set_command( "focus_view" );
+        // 各ボタンの状態更新
+        get_messagetoolbar()->m_button_undo.set_sensitive( true );
+        get_messagetoolbar()->m_button_open.set_sensitive( true );
+        get_messagetoolbar()->m_button_preview.set_active( false );
     }
+
+    if( m_enable_focus ){
+        MESSAGE::get_admin()->set_command( "switch_admin" );
+        MESSAGE::get_admin()->set_command( "focus_current_view" );
+    }
+
+    m_enable_menuslot = true;
 }
 
 
@@ -593,13 +838,12 @@ void MessageViewBase::show_status()
     ss << "   /  文字数 " << m_lng_str_enc;
     if( m_max_str ) ss << "/ " << m_max_str;
 
+    if( DBTREE::article_write_time( get_url() ) ) ss << "  /  最終書込 " << DBTREE::article_write_date( get_url() );
+
     ss << " ]";
 
-#if GTKMMVER <= 240
-    m_statbar.push( ss.str() );
-#else
-    m_label_stat.set_text( ss.str() );
-#endif        
+    set_status( ss.str() );
+    MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() + m_str_pass );
 }
 
 
@@ -609,7 +853,8 @@ void MessageViewBase::save_postlog()
 {
     if( ! CONFIG::get_save_postlog() ) return;
 
-    std::string subject = get_entry_subject().get_text();
+    std::string subject;
+    if( get_entry_subject() ) subject = get_entry_subject()->get_text();
     std::string msg = get_text_message().get_text();
     std::string name = get_entry_name().get_text();
     std::string mail = get_entry_mail().get_text();
